@@ -96,7 +96,7 @@
 #define _OS_ULTRIX_
 #elif defined(reliantunix)
 #define _OS_RELIANTUNIX_
-#elif defined(linux) || defined(__linux) || defined(__linux__)
+#elif defined(linux) || defined(__linux) || defined(__linux__) || defined(__GNU__) || defined(__GLIBC__)
 #define _OS_LINUX_
 #elif defined(__FreeBSD__)
 #define _OS_FREEBSD_
@@ -116,8 +116,6 @@
 #define _OS_LYNXOS_
 #elif defined(_UNIXWARE)
 #define _OS_UNIXWARE_
-#elif defined(__GNU__)
-#define _OS_GNU_
 #elif defined(DGUX)
 #define _OS_DGUX_
 #elif defined(__QNX__)
@@ -132,6 +130,8 @@
 #define _OS_CYGWIN_
 #elif defined(__BEOS__)
 #define _OS_BEOS_
+#elif defined(__MINT__)
+#define _OS_MINT_
 #else
 #error "Qt has not been ported to this OS - talk to qt-bugs@trolltech.com"
 #endif
@@ -262,6 +262,19 @@
 #error "Qt has not been tested with this compiler - talk to qt-bugs@trolltech.com"
 #endif
 
+// detect Microsoft compiler version
+#ifdef _CC_MSVC_
+#if _MSC_VER >= 1400
+#define _CC_V2005
+#elif _MSC_VER >= 1310
+#define _CC_V2003
+#elif _MSC_VER > 1300
+#define _CC_V2002
+#else
+#define _CC_V1998
+#endif 
+#endif
+
 #ifndef Q_PACKED
 #define Q_PACKED
 #endif
@@ -336,6 +349,13 @@ typedef unsigned long	ulong;
 typedef char	       *pchar;
 typedef uchar	       *puchar;
 typedef const char     *pcchar;
+#if defined(_OS_WIN32_) && !defined(_CC_GNU_)
+typedef __int64            int64;
+typedef unsigned __int64   uint64;
+#else
+typedef long long          int64;
+typedef unsigned long long uint64;
+#endif
 
 
 //
