@@ -147,8 +147,22 @@
 "    <xsd:attribute name=\"virt\" type=\"DoxVirtualKind\" />\n"
 "    <xsd:attribute name=\"volatile\" type=\"DoxBool\" />\n"
 "    <xsd:attribute name=\"mutable\" type=\"DoxBool\" />\n"
+"    <!-- Qt property -->\n"
 "    <xsd:attribute name=\"readable\" type=\"DoxBool\" use=\"optional\"/>\n"
 "    <xsd:attribute name=\"writable\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <!-- C++/CLI variable -->\n"
+"    <xsd:attribute name=\"initonly\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <!-- C++/CLI and C# property -->\n"
+"    <xsd:attribute name=\"settable\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <xsd:attribute name=\"gettable\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <!-- C++/CLI function -->\n"
+"    <xsd:attribute name=\"final\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <xsd:attribute name=\"sealed\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <xsd:attribute name=\"new\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <!-- C++/CLI event -->\n"
+"    <xsd:attribute name=\"add\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <xsd:attribute name=\"remove\" type=\"DoxBool\" use=\"optional\"/>\n"
+"    <xsd:attribute name=\"raise\" type=\"DoxBool\" use=\"optional\"/>\n"
 "  </xsd:complexType>\n"
 "\n"
 "  <xsd:complexType name=\"descriptionType\" mixed=\"true\">\n"
