@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -133,6 +133,7 @@ void doctokenizerYYsetStateLatexOnly();
 void doctokenizerYYsetStateXmlOnly();
 void doctokenizerYYsetStateVerbatim();
 void doctokenizerYYsetStateDot();
+void doctokenizerYYsetStateMsc();
 void doctokenizerYYsetStateParam();
 void doctokenizerYYsetStateXRefItem();
 void doctokenizerYYsetStateFile();
@@ -143,5 +144,6 @@ void doctokenizerYYsetStateInternalRef();
 void doctokenizerYYsetStateText();
 void doctokenizerYYsetStateSkipTitle();
 void doctokenizerYYsetInsidePre(bool b);
+void doctokenizerYYpushBackHtmlTag(const char *tag);
 
 #endif
