@@ -3,7 +3,7 @@
  * $Id: doxygen.h,v 1.39 2001/03/19 19:27:40 root Exp $
  *
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -43,6 +43,8 @@ class PageDef;
 class SearchIndex;
 class DirDef;
 class ParserManager;
+class ObjCache;
+class Store;
 
 typedef QList<QCString>    StringList;
 typedef QDict<FileDef>     FileDict;
@@ -57,11 +59,13 @@ class StringDict : public QDict<QCString>
 
 struct LookupInfo
 {
-  LookupInfo(ClassDef *cd=0,MemberDef *td=0,QCString ts="") 
-    : classDef(cd), typeDef(td), templSpec(ts) {}
+  LookupInfo() : classDef(0), typeDef(0) {}
+  LookupInfo(ClassDef *cd,MemberDef *td,QCString ts,QCString rt) 
+    : classDef(cd), typeDef(td), templSpec(ts),resolvedType(rt) {}
   ClassDef  *classDef;
   MemberDef *typeDef;
   QCString   templSpec;
+  QCString   resolvedType;
 };
 
 extern QCString spaces;
@@ -73,8 +77,8 @@ extern QCString spaces;
 class Doxygen
 {
   public:
-    static ClassSDict                classSDict;
-    static ClassSDict                hiddenClasses;
+    static ClassSDict               *classSDict;
+    static ClassSDict               *hiddenClasses;
     static PageSDict                *exampleSDict;
     static PageSDict                *pageSDict;
     static PageDef                  *mainPage;
@@ -82,20 +86,17 @@ class Doxygen
     static FileNameDict             *includeNameDict;
     static FileNameDict             *exampleNameDict;
     static FileNameDict             *inputNameDict;
-    static FileNameList              inputNameList;
+    static FileNameList             *inputNameList;
     static FileNameDict             *imageNameDict;
     static FileNameDict             *dotFileNameDict;
     static QStrList                  tagfileList;
-    static MemberNameSDict           memberNameSDict;
-    static MemberNameSDict           functionNameSDict;
-    static FileList                  fileList;
-    static FileDict                  fileDict;
-    static ClassDef                  unrelatedClass; 
+    static MemberNameSDict          *memberNameSDict;
+    static MemberNameSDict          *functionNameSDict;
     static QTextStream               tagFile;
     static SectionDict               sectionDict;
     static StringDict                namespaceAliasDict;
-    static GroupSDict                groupSDict;
-    static NamespaceSDict            namespaceSDict;
+    static GroupSDict               *groupSDict;
+    static NamespaceSDict           *namespaceSDict;
     static FormulaList               formulaList;
     static FormulaDict               formulaDict;
     static FormulaDict               formulaNameDict;
@@ -110,18 +111,23 @@ class Doxygen
     static double                    sysElapsedTime;
     static QTime                     runningTime;
     static SearchIndex              *searchIndex;
-    static SDict<DefinitionList>    *symbolMap;
+    static QDict<DefinitionIntf>    *symbolMap;
     static bool                      outputToWizard;
     static QDict<int>               *htmlDirMap;
     static QCache<LookupInfo>        lookupCache;
-    static DirSDict                  directories;
+    static DirSDict                 *directories;
     static SDict<DirRelation>        dirRelations;
     static ParserManager            *parserManager;
     static bool                      suppressDocWarnings;
+    static ObjCache                 *symbolCache;
+    static Store                    *symbolStorage;
+    static QCString                  objDBFileName;
+    static QCString                  entryDBFileName;
 };
 
 void initDoxygen();
 void readConfiguration(int argc, char **argv);
+void checkConfiguration();
 void parseInput();
 void generateOutput();
 
