@@ -369,6 +369,8 @@ void FTVHelp::initialize()
 void FTVHelp::finalize()
 {
   generateTreeView();
+  delete m_theInstance;
+  m_theInstance=0;
 }
 
 /*! Increase the level of the contents hierarchy. 
@@ -594,8 +596,7 @@ void FTVHelp::generateTreeView()
 #endif
     t << "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Transitional//EN\">\n";
     t << "<html><head>";
-    t << "<meta http-equiv=\"Content-Type\" content=\"text/html;charset="
-      << theTranslator->idLanguageCharset() << "\">\n";
+    t << "<meta http-equiv=\"Content-Type\" content=\"text/html;charset=UTF-8\">\n";
     t << "<title>"; 
     if (Config_getString("PROJECT_NAME").isEmpty())
     {
@@ -609,6 +610,9 @@ void FTVHelp::generateTreeView()
     t << "<frameset cols=\"" << Config_getInt("TREEVIEW_WIDTH") << ",*\">" << endl;
     t << "  <frame src=\"tree" << Doxygen::htmlFileExtension << "\" name=\"treefrm\">" << endl;
     t << "  <frame src=\"main" << Doxygen::htmlFileExtension << "\" name=\"basefrm\">" << endl;
+    t << "  <noframes>" << endl;
+    t << "    <a href=\"main.html\">Frames are disabled. Click here to go to the main page.</a>" << endl;
+    t << "  </noframes>" << endl;
     t << "</frameset>" << endl;
     t << "</html>" << endl;
     f.close();
@@ -630,8 +634,7 @@ void FTVHelp::generateTreeView()
 #endif
     t << "<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"en\" lang=\"en\">\n";
     t << "  <head>\n";
-    t << "    <meta http-equiv=\"Content-Type\" content=\"text/xhtml;charset="
-      << theTranslator->idLanguageCharset() << "\" />\n";
+    t << "    <meta http-equiv=\"Content-Type\" content=\"text/xhtml;charset=UTF-8\" />\n";
     t << "    <meta http-equiv=\"Content-Style-Type\" content=\"text/css\" />\n";
     t << "    <meta http-equiv=\"Content-Language\" content=\"en\" />\n";
     t << "    <link rel=\"stylesheet\" href=\"";
@@ -651,66 +654,32 @@ void FTVHelp::generateTreeView()
     }
     t << "\">" << endl;
     t << "    <title>TreeView</title>\n";
-    t << "    <style type=\"text/css\">\n";
-    t << "    <!--\n";
-    t << "    .directory { font-size: 10pt; font-weight: bold; }\n";
-    t << "    .directory h3 { margin: 0px; margin-top: 1em; font-size: 11pt; }\n";
-    t << "    .directory p { margin: 0px; white-space: nowrap; }\n";
-    t << "    .directory div { display: none; margin: 0px; }\n";
-    t << "    .directory img { vertical-align: middle; }\n";
-    t << "    -->\n";
-    t << "    </style>\n";
     t << "    <script type=\"text/javascript\">\n";
     t << "    <!-- // Hide script from old browsers\n";
     t << "    \n";
-    t << "    function findChildNode(node, name) \n";
-    t << "    {\n";
-    t << "      var temp;\n";
-    t << "      if (node == null) \n";
-    t << "      {\n";
-    t << "        return null;\n";
-    t << "      } \n";
-    t << "      node = node.firstChild;\n";
-    t << "      while (node != null) \n";
-    t << "      {\n";
-    t << "        if (node.nodeName == name) \n";
-    t << "        {\n";
-    t << "          return node;\n";
-    t << "        }\n";
-    t << "        temp = findChildNode(node, name);\n";
-    t << "        if (temp != null) \n";
-    t << "        {\n";
-    t << "          return temp;\n";
-    t << "        }\n";
-    t << "        node = node.nextSibling;\n";
-    t << "      }\n";
-    t << "      return null;\n";
-    t << "    }\n";
-    t << "\n";
+
+            /* User has clicked on a node (folder or +/-) in the tree */
     t << "    function toggleFolder(id, imageNode) \n";
     t << "    {\n";
     t << "      var folder = document.getElementById(id);\n";
-    t << "      var l = 0;\n";
-    t << "      var vl = \"" FTV_ICON_FILE(vertline) "\";\n";
-    t << "      if (imageNode != null && imageNode.nodeName != \"IMG\") \n";
+    t << "      var l = imageNode.src.length;\n";
+                /* If the user clicks on the book icon, we move left one image so 
+                 * the code (below) will also adjust the '+' icon. 
+                 */
+    t << "      if (imageNode.src.substring(l-20,l)==\"" FTV_ICON_FILE(folderclosed) "\" || \n";
+    t << "          imageNode.src.substring(l-18,l)==\"" FTV_ICON_FILE(folderopen)  "\")\n";
     t << "      {\n";
-    t << "        imageNode = findChildNode(imageNode, \"IMG\");\n";
-    t << "        if (imageNode!=null) l = imageNode.src.length;\n";
+    t << "        imageNode = imageNode.previousSibling;\n";
+    t << "        l = imageNode.src.length;\n";
     t << "      }\n";
     t << "      if (folder == null) \n";
     t << "      {\n";
     t << "      } \n";
+                /* Node controls a open section, we need to close it */
     t << "      else if (folder.style.display == \"block\") \n";
     t << "      {\n";
-    t << "        while (imageNode != null && \n";
-    t << "               imageNode.src.substring(l-vl.length,l) == vl)\n";
-    t << "        {\n";
-    t << "          imageNode = imageNode.nextSibling;\n";
-    t << "          l = imageNode.src.length;\n";
-    t << "        }\n";
     t << "        if (imageNode != null) \n";
     t << "        {\n";
-    t << "          l = imageNode.src.length;\n";
     t << "          imageNode.nextSibling.src = \"" FTV_ICON_FILE(folderclosed) "\";\n";
     t << "          if (imageNode.src.substring(l-13,l) == \"" FTV_ICON_FILE(mnode) "\")\n";
     t << "          {\n";
@@ -723,17 +692,10 @@ void FTVHelp::generateTreeView()
     t << "        }\n";
     t << "        folder.style.display = \"none\";\n";
     t << "      } \n";
-    t << "      else \n";
+    t << "      else \n"; /* section is closed, we need to open it */
     t << "      {\n";
-    t << "        while (imageNode != null && \n";
-    t << "               imageNode.src.substring(l-vl.length,l) == vl)\n";
-    t << "        {\n";
-    t << "          imageNode = imageNode.nextSibling;\n";
-    t << "          l = imageNode.src.length;\n";
-    t << "        }\n";
     t << "        if (imageNode != null) \n";
     t << "        {\n";
-    t << "          l = imageNode.src.length;\n";
     t << "          imageNode.nextSibling.src = \"" FTV_ICON_FILE(folderopen) "\";\n";
     t << "          if (imageNode.src.substring(l-13,l) == \"" FTV_ICON_FILE(pnode) "\")\n";
     t << "          {\n";
@@ -752,7 +714,7 @@ void FTVHelp::generateTreeView()
     t << "    </script>\n";
     t << "  </head>\n";
     t << "\n";
-    t << "  <body>\n";
+    t << "  <body class=\"ftvtree\">\n";
     t << "    <div class=\"directory\">\n";
     t << "      <h3>";
     QCString &projName = Config_getString("PROJECT_NAME");
