@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -27,6 +27,7 @@
 #include "config.h"
 #include "htmlgen.h"
 #include "parserintf.h"
+#include "msc.h"
 
 
 static const int NUM_HTML_LIST_TYPES = 4;
@@ -69,7 +70,7 @@ void HtmlDocVisitor::visit(DocWord *w)
 void HtmlDocVisitor::visit(DocLinkedWord *w)
 {
   if (m_hide) return;
-  startLink(w->ref(),w->file(),w->relPath(),w->anchor());
+  startLink(w->ref(),w->file(),w->relPath(),w->anchor(),w->tooltip());
   filter(w->word());
   endLink();
 }
@@ -101,7 +102,7 @@ void HtmlDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Hash:    m_t << "#"; break;
     case DocSymbol::Percent: m_t << "%"; break;
     case DocSymbol::Copy:    m_t << "&copy;"; break;
-    case DocSymbol::Tm:      m_t << "&tm;"; break;
+    case DocSymbol::Tm:      m_t << "&trade;"; break;
     case DocSymbol::Reg:     m_t << "&reg;"; break;
     case DocSymbol::Apos:    m_t << "'"; break;
     case DocSymbol::Quot:    m_t << "\""; break;
@@ -228,9 +229,10 @@ void HtmlDocVisitor::visit(DocVerbatim *s)
         static int dotindex = 1;
         QCString fileName(4096);
 
-        fileName.sprintf("%s%d", 
+        fileName.sprintf("%s%d%s", 
             (Config_getString("HTML_OUTPUT")+"/inline_dotgraph_").data(), 
-            dotindex++
+            dotindex++,
+            ".dot"
            );
         QFile file(fileName);
         if (!file.open(IO_WriteOnly))
@@ -244,7 +246,34 @@ void HtmlDocVisitor::visit(DocVerbatim *s)
         writeDotFile(fileName,s->relPath());
         m_t << "</div>" << endl;
 
-        file.remove();
+        if (Config_getBool("DOT_CLEANUP")) file.remove();
+      }
+      break;
+    case DocVerbatim::Msc:
+      {
+        static int mscindex = 1;
+        QCString baseName(4096);
+
+        baseName.sprintf("%s%d", 
+            (Config_getString("HTML_OUTPUT")+"/inline_mscgraph_").data(), 
+            mscindex++
+           );
+        QFile file(baseName+".msc");
+        if (!file.open(IO_WriteOnly))
+        {
+          err("Could not open file %s.msc for writing\n",baseName.data());
+        }
+        QCString text = "msc {";
+        text+=s->text();
+        text+="}";
+        file.writeBlock( text, text.length() );
+        file.close();
+
+        m_t << "<div align=\"center\">" << endl;
+        writeMscFile(baseName,s->relPath());
+        m_t << "</div>" << endl;
+
+        if (Config_getBool("DOT_CLEANUP")) file.remove();
       }
       break;
   }
@@ -444,7 +473,7 @@ void HtmlDocVisitor::visitPost(DocRoot *)
 void HtmlDocVisitor::visitPre(DocSimpleSect *s)
 {
   if (m_hide) return;
-  m_t << "<dl compact><dt><b>";
+  m_t << "<dl class=\"" << s->typeString() << "\" compact><dt><b>";
   switch(s->type())
   {
     case DocSimpleSect::See: 
@@ -1062,7 +1091,8 @@ void HtmlDocVisitor::filterQuotedCdataAttr(const char* str)
 }
 
 void HtmlDocVisitor::startLink(const QString &ref,const QString &file,
-                               const QString &relPath,const QString &anchor)
+                               const QString &relPath,const QString &anchor,
+                               const QString &tooltip)
 {
   QCString *dest;
   if (!ref.isEmpty()) // link to entity imported via tag file
@@ -1079,7 +1109,7 @@ void HtmlDocVisitor::startLink(const QString &ref,const QString &file,
   m_t << "href=\"";
   if (!ref.isEmpty())
   {
-    if ((dest=Doxygen::tagDestinationDict[ref])) m_t << relPath << *dest << "/";
+    if ((dest=Doxygen::tagDestinationDict[ref])) m_t << *dest << "/";
   }
   else
   {
@@ -1087,7 +1117,9 @@ void HtmlDocVisitor::startLink(const QString &ref,const QString &file,
   }
   if (!file.isEmpty()) m_t << file << Doxygen::htmlFileExtension;
   if (!anchor.isEmpty()) m_t << "#" << anchor;
-  m_t << "\">";
+  m_t << "\"";
+  if (!tooltip.isEmpty()) m_t << " title=\"" << tooltip << "\"";
+  m_t << ">";
 }
 
 void HtmlDocVisitor::endLink()
@@ -1127,3 +1159,21 @@ void HtmlDocVisitor::writeDotFile(const QString &fileName,const QString &relPath
   m_t << "<map name=\"" << mapName << "\">" << imap << "</map>" << endl;
 }
 
+void HtmlDocVisitor::writeMscFile(const QString &fileName,const QString &relPath)
+{
+  QString baseName=fileName;
+  int i;
+  if ((i=baseName.findRev('/'))!=-1)
+  {
+    baseName=baseName.right(baseName.length()-i-1);
+  } 
+  QString outDir = Config_getString("HTML_OUTPUT");
+  writeMscGraphFromFile(fileName,outDir,baseName,MSC_BITMAP);
+  QString mapName = baseName+".map";
+  QString mapFile = fileName+".map";
+  m_t << "<img src=\"" << relPath << baseName << ".png\" alt=\""
+    << baseName << "\" border=\"0\" usemap=\"#" << mapName << "\">" << endl;
+  QString imap = getMscImageMapFromFile(fileName,outDir,relPath.data());
+  m_t << "<map name=\"" << mapName << "\">" << imap << "</map>" << endl;
+}
+
