@@ -2,7 +2,7 @@
  *
  * $Id: htmlgen.h,v 1.51 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -72,13 +72,15 @@ class HtmlGenerator : public OutputGenerator
     void endIndexValue(const char *,bool);
     void startItemList()  { t << "<ul>"  << endl; }
     void endItemList()    { t << "</ul>" << endl; }
-    void writeIndexItem(const char *ref,const char *file,const char *name);
+    void startIndexItem(const char *ref,const char *file);
+    void endIndexItem(const char *ref,const char *file);
     void docify(const char *text);
     void codify(const char *text);
     void writeObjectLink(const char *ref,const char *file,
                          const char *anchor,const char *name);
     void writeCodeLink(const char *ref,const char *file,
-                       const char *anchor,const char *name);
+                       const char *anchor,const char *name,
+                       const char *tooltip);
     void startTextLink(const char *file,const char *anchor);
     void endTextLink();
     void startHtmlLink(const char *url);
@@ -222,6 +224,8 @@ class HtmlGenerator : public OutputGenerator
 
     void writeCodeAnchor(const char *anchor) 
     { t << "<a name=\"" << anchor << "\"></a>"; }
+    void linkableSymbol(int,const char *,Definition *,Definition *) {}
+
     static void writeSearchPage();
 
   private:
