@@ -2,7 +2,7 @@
  *
  * $Id: htmlhelp.cpp,v 1.8 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -446,6 +446,10 @@ void HtmlHelp::createProjectFile()
       t << s << endl;
       s = indexFiles.next();
     }
+    t << "tabs.css" << endl;
+    t << "tab_b.gif" << endl;
+    t << "tab_l.gif" << endl;
+    t << "tab_r.gif" << endl;
     f.close();
   }
   else
