@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -25,6 +25,7 @@
 #include "util.h"
 #include "message.h"
 #include "parserintf.h"
+#include "msc.h"
 
 static QString escapeLabelName(const char *s)
 {
@@ -36,7 +37,7 @@ static QString escapeLabelName(const char *s)
     switch (c)
     {
       case '%': result+="\\%"; break;
-      case '|': result+="\\tt{\"|}"; break;
+      case '|': result+="\\texttt{\"|}"; break;
       case '!': result+="\"!"; break;
       default: result+=c;
     }
@@ -69,7 +70,7 @@ QString LatexDocVisitor::escapeMakeIndexChars(const char *s)
       case '!': m_t << "\"!"; break;
       case '"': m_t << "\"\""; break;
       case '@': m_t << "\"@"; break;
-      case '|': m_t << "\\tt{\"|}"; break;
+      case '|': m_t << "\\texttt{\"|}"; break;
       case '[': m_t << "["; break;
       case ']': m_t << "]"; break;
       default:  str[0]=c; filter(str); break;
@@ -191,7 +192,7 @@ void LatexDocVisitor::visit(DocURL *u)
     if (u->isEmail()) m_t << "mailto:";
     m_t << u->url() << "}";
   }
-  m_t << "\\tt{";
+  m_t << "{\\tt ";
   filter(u->url());
   m_t << "}";
 }
@@ -232,7 +233,7 @@ void LatexDocVisitor::visit(DocStyleChange *s)
       if (s->enable()) m_t << "\\begin{center}"; else m_t << "\\end{center} ";
       break;
     case DocStyleChange::Small:
-      if (s->enable()) m_t << "\\footnotesize ";  else m_t << "\\normalsize ";
+      if (s->enable()) m_t << "\n\\footnotesize ";  else m_t << "\n\\normalsize ";
       break;
     case DocStyleChange::Preformatted:
       if (s->enable()) 
@@ -243,7 +244,7 @@ void LatexDocVisitor::visit(DocStyleChange *s)
       else
       {
         m_insidePre=FALSE;
-        m_t << "\\end{alltt}\\normalsize " << endl;
+        m_t << "\\end{alltt}\n\\normalsize " << endl;
       }
       break;
     case DocStyleChange::Div:  /* HTML only */ break;
@@ -261,7 +262,7 @@ void LatexDocVisitor::visit(DocVerbatim *s)
       Doxygen::parserManager->getParser(m_langExt)
                             ->parseCode(m_ci,s->context(),s->text().latin1(),
                                         s->isExample(),s->exampleFile());
-      m_t << "\\end{verbatim}\\end{Code}\n" << endl; 
+      m_t << "\\end{verbatim}\n\\end{Code}\n" << endl; 
       break;
     case DocVerbatim::Verbatim: 
       m_t << "\n\n\\footnotesize\\begin{verbatim}"; 
@@ -281,9 +282,10 @@ void LatexDocVisitor::visit(DocVerbatim *s)
         static int dotindex = 1;
         QCString fileName(4096);
 
-        fileName.sprintf("%s%d", 
+        fileName.sprintf("%s%d%s", 
             (Config_getString("LATEX_OUTPUT")+"/inline_dotgraph_").data(), 
-            dotindex++
+            dotindex++,
+            ".dot"
            );
         QFile file(fileName);
         if (!file.open(IO_WriteOnly))
@@ -298,7 +300,34 @@ void LatexDocVisitor::visit(DocVerbatim *s)
         endDotFile(FALSE);
         m_t << "\\end{center}\n";
 
-        file.remove();
+        if (Config_getBool("DOT_CLEANUP")) file.remove();
+      }
+      break;
+    case DocVerbatim::Msc: 
+      {
+        static int mscindex = 1;
+        QCString baseName(4096);
+
+        baseName.sprintf("%s%d", 
+            (Config_getString("LATEX_OUTPUT")+"/inline_mscgraph_").data(), 
+            mscindex++
+           );
+        QFile file(baseName+".msc");
+        if (!file.open(IO_WriteOnly))
+        {
+          err("Could not open file %s.msc for writing\n",baseName.data());
+        }
+        QCString text = "msc {";
+        text+=s->text();
+        text+="}";
+        file.writeBlock( text, text.length() );
+        file.close();
+
+        m_t << "\\begin{center}\n";
+        writeMscFile(baseName);
+        m_t << "\\end{center}\n";
+
+        if (Config_getBool("DOT_CLEANUP")) file.remove();
       }
       break;
   }
@@ -972,7 +1001,7 @@ void LatexDocVisitor::visitPre(DocXRefItem *x)
   }
   else
   {
-    m_t << "\\bf{";
+    m_t << "{\\bf ";
   }
   m_insideItem=TRUE;
   filter(x->title());
@@ -1021,18 +1050,33 @@ void LatexDocVisitor::filter(const char *str)
 
 void LatexDocVisitor::startLink(const QString &ref,const QString &file,const QString &anchor)
 {
-  if (ref.isEmpty() && Config_getBool("PDF_HYPERLINKS"))
+  if (ref.isEmpty() && Config_getBool("PDF_HYPERLINKS")) // internal PDF link 
   {
-    m_t << "\\hyperlink{";
-    if (!file.isEmpty()) m_t << stripPath(file);
-    if (!file.isEmpty() && !anchor.isEmpty()) m_t << "_";
-    if (!anchor.isEmpty()) m_t << anchor;
-    m_t << "}{";
+    if (ref.isEmpty()) {
+      m_t << "\\hyperlink{";
+      if (!file.isEmpty()) m_t << stripPath(file);
+      if (!file.isEmpty() && !anchor.isEmpty()) m_t << "_";
+      if (!anchor.isEmpty()) m_t << anchor;
+      m_t << "}{";
+    }
+    else
+    {
+      QCString *dest;
+      m_t << "\\href{";
+      if ((dest=Doxygen::tagDestinationDict[ref])) m_t << *dest << "/";
+      if (!file.isEmpty()) m_t << file << Doxygen::htmlFileExtension;
+      if (!anchor.isEmpty()) m_t << "#" << anchor;
+      m_t << "}{";
+    }
   }
-  else
+  else if (ref.isEmpty()) // internal non-PDF link
   {
     m_t << "\\doxyref{";
   }
+  else // external link
+  { 
+    m_t << "{\\bf ";
+  }
 }
 
 void LatexDocVisitor::endLink(const QString &ref,const QString &file,const QString &anchor)
@@ -1125,3 +1169,23 @@ void LatexDocVisitor::endDotFile(bool hasCaption)
   }
 }
 
+void LatexDocVisitor::writeMscFile(const QString &baseName)
+{
+  QString outDir = Config_getString("LATEX_OUTPUT");
+  writeMscGraphFromFile(baseName,outDir,baseName,MSC_EPS);
+  m_t << "\\begin{ImageNoCaption}\\mbox{";
+  m_t << "\\includegraphics";
+  //if (!width.isEmpty())
+  //{
+  //  m_t << "[width=" << width << "]";
+  //}
+  //else if (!height.isEmpty())
+  //{
+  //  m_t << "[height=" << height << "]";
+  //}
+  m_t << "{" << baseName << "}";
+
+  m_t << "}" << endl; // end mbox
+  m_t << "\\end{ImageNoCaption}" << endl;
+}
+
