@@ -2,7 +2,7 @@
  *
  * $Id: latexgen.cpp,v 1.58 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -102,7 +102,9 @@ LatexGenerator::LatexGenerator() : OutputGenerator()
   //printf("LatexGenerator::LatexGenerator() insideTabbing=FALSE\n");
   insideTabbing=FALSE;
   firstDescItem=TRUE;
+  disableLinks=FALSE;
   m_indent=0;
+  templateMemberItem = FALSE;
 }
 
 LatexGenerator::~LatexGenerator()
@@ -239,19 +241,22 @@ static void writeDefaultHeaderPart1(QTextStream &t)
       << "\\usepackage[ps2pdf," << endl
       << "            pagebackref=true," << endl
       << "            colorlinks=true," << endl
-      << "            linkcolor=blue" << endl
+      << "            linkcolor=blue," << endl
+      << "            unicode" << endl
       << "           ]{hyperref}" << endl
       << "\\usepackage{pspicture}" << endl
       << "\\else" << endl
       << "\\usepackage[pdftex," << endl
       << "            pagebackref=true," << endl
       << "            colorlinks=true," << endl
-      << "            linkcolor=blue" << endl
+      << "            linkcolor=blue," << endl
+      << "            unicode" << endl
       << "           ]{hyperref}" << endl
       << "\\fi" << endl;
   }
   // Try to get the command for switching on the language
   // support
+  t << "\\usepackage[utf8]{inputenc}" << endl;
   QCString sLanguageSupportCommand(
       theTranslator->latexLanguageSupportCommand());
 
@@ -261,7 +266,6 @@ static void writeDefaultHeaderPart1(QTextStream &t)
     // if the command is empty, no output is needed.
     t << sLanguageSupportCommand << endl;
   }
-
   t << "\\usepackage{doxygen}\n";
   QStrList &extraPackages = Config_getList("EXTRA_PACKAGES");
   const char *s=extraPackages.first();
@@ -425,17 +429,20 @@ void LatexGenerator::writeStyleSheetFile(QFile &f)
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2006";
+  //t << "Dimitri van Heesch \\copyright~1997-2007";
   writeDefaultStyleSheetPart2(t);
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2006";
+  //t << "Dimitri van Heesch \\copyright~1997-2007";
   writeDefaultStyleSheetPart3(t);
 }
 
 void LatexGenerator::startFile(const char *name,const char *,const char *)
 {
+#if 0
+  setEncoding(Config_getString("LATEX_OUTPUT_ENCODING"));
+#endif
   QCString fileName=name;
   relPath = relativePathToRoot(fileName);
   if (fileName.right(4)!=".tex" && fileName.right(4)!=".sty") fileName+=".tex";
@@ -520,7 +527,7 @@ void LatexGenerator::startIndexSection(IndexSections is)
       break;
     case isModuleDocumentation:
       {
-        GroupSDict::Iterator gli(Doxygen::groupSDict);
+        GroupSDict::Iterator gli(*Doxygen::groupSDict);
         GroupDef *gd;
         bool found=FALSE;
         for (gli.toFirst();(gd=gli.current()) && !found;++gli)
@@ -536,7 +543,7 @@ void LatexGenerator::startIndexSection(IndexSections is)
       break;
     case isDirDocumentation:
       {
-        SDict<DirDef>::Iterator dli(Doxygen::directories);
+        SDict<DirDef>::Iterator dli(*Doxygen::directories);
         DirDef *dd;
         bool found=FALSE;
         for (dli.toFirst();(dd=dli.current()) && !found;++dli)
@@ -552,7 +559,7 @@ void LatexGenerator::startIndexSection(IndexSections is)
       break;
     case isNamespaceDocumentation:
       {
-        NamespaceSDict::Iterator nli(Doxygen::namespaceSDict);
+        NamespaceSDict::Iterator nli(*Doxygen::namespaceSDict);
         NamespaceDef *nd;
         bool found=FALSE;
         for (nli.toFirst();(nd=nli.current()) && !found;++nli)
@@ -568,7 +575,7 @@ void LatexGenerator::startIndexSection(IndexSections is)
       break;
     case isClassDocumentation:
       {
-        ClassSDict::Iterator cli(Doxygen::classSDict);
+        ClassSDict::Iterator cli(*Doxygen::classSDict);
         ClassDef *cd=0;
         bool found=FALSE;
         for (cli.toFirst();(cd=cli.current()) && !found;++cli)
@@ -585,7 +592,7 @@ void LatexGenerator::startIndexSection(IndexSections is)
     case isFileDocumentation:
       {
         bool isFirst=TRUE;
-        FileName *fn=Doxygen::inputNameList.first();
+        FileName *fn=Doxygen::inputNameList->first();
         while (fn)
         {
           FileDef *fd=fn->first();
@@ -603,7 +610,7 @@ void LatexGenerator::startIndexSection(IndexSections is)
             }
             fd=fn->next();
           }
-          fn=Doxygen::inputNameList.next();
+          fn=Doxygen::inputNameList->next();
         }
       }
       break;
@@ -670,7 +677,7 @@ void LatexGenerator::endIndexSection(IndexSections is)
       break;
     case isModuleDocumentation:
       {
-        GroupSDict::Iterator gli(Doxygen::groupSDict);
+        GroupSDict::Iterator gli(*Doxygen::groupSDict);
         GroupDef *gd;
         bool found=FALSE;
         for (gli.toFirst();(gd=gli.current()) && !found;++gli)
@@ -693,7 +700,7 @@ void LatexGenerator::endIndexSection(IndexSections is)
       break;
     case isDirDocumentation:
       {
-        SDict<DirDef>::Iterator dli(Doxygen::directories);
+        SDict<DirDef>::Iterator dli(*Doxygen::directories);
         DirDef *dd;
         bool found=FALSE;
         for (dli.toFirst();(dd=dli.current()) && !found;++dli)
@@ -716,7 +723,7 @@ void LatexGenerator::endIndexSection(IndexSections is)
       break;
     case isNamespaceDocumentation:
       {
-        NamespaceSDict::Iterator nli(Doxygen::namespaceSDict);
+        NamespaceSDict::Iterator nli(*Doxygen::namespaceSDict);
         NamespaceDef *nd;
         bool found=FALSE;
         for (nli.toFirst();(nd=nli.current()) && !found;++nli)
@@ -740,7 +747,7 @@ void LatexGenerator::endIndexSection(IndexSections is)
       break;
     case isClassDocumentation:
       {
-        ClassSDict::Iterator cli(Doxygen::classSDict);
+        ClassSDict::Iterator cli(*Doxygen::classSDict);
         ClassDef *cd=0;
         bool found=FALSE;
         for (cli.toFirst();(cd=cli.current()) && !found;++cli)
@@ -764,7 +771,7 @@ void LatexGenerator::endIndexSection(IndexSections is)
     case isFileDocumentation:
       {
         bool isFirst=TRUE;
-        FileName *fn=Doxygen::inputNameList.first();
+        FileName *fn=Doxygen::inputNameList->first();
         while (fn)
         {
           FileDef *fd=fn->first();
@@ -785,7 +792,7 @@ void LatexGenerator::endIndexSection(IndexSections is)
             }
             fd=fn->next();
           }
-          fn=Doxygen::inputNameList.next();
+          fn=Doxygen::inputNameList->next();
         }
       }
       break;
@@ -845,14 +852,14 @@ void LatexGenerator::writeStyleInfo(int part)
       break;
     case 2:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2006";
+        //t << " Dimitri van Heesch \\copyright~1997-2007";
         t << "}]{}\n";
         writeDefaultStyleSheetPart2(t);
       }
       break;
     case 4:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2006";
+        //t << " Dimitri van Heesch \\copyright~1997-2007";
         writeDefaultStyleSheetPart3(t);
         endPlainFile();
       }
@@ -870,18 +877,21 @@ void LatexGenerator::writeString(const char *text)
   t << text;
 }
 
-void LatexGenerator::writeIndexItem(const char *ref,const char *fn,
-                                    const char *name)
+void LatexGenerator::startIndexItem(const char *ref,const char *fn)
 {
   t << "\\item ";
   if (!ref && fn)
   {
     t << "\\contentsline{section}{";
-    docify(name);
+  }
+}
+
+void LatexGenerator::endIndexItem(const char *ref,const char *fn)
+{
+  if (!ref && fn)
+  {
     t << "}{\\pageref{" << fn << "}}{}" << endl;
   }
-  else
-    docify(name);
 }
 
 //void LatexGenerator::writeIndexFileItem(const char *,const char *text)
@@ -959,14 +969,14 @@ void LatexGenerator::endIndexValue(const char *name,bool hasBrief)
 //void LatexGenerator::writeClassLink(const char *,const char *,
 //                                    const char *,const char *name)
 //{
-//  t << "{\\bf";
+//  t << "{\\bf ";
 //  docify(name);
 //  t << "}"; 
 //}
 
 void LatexGenerator::startTextLink(const char *f,const char *anchor)
 {
-  if (Config_getBool("PDF_HYPERLINKS"))
+  if (!disableLinks && Config_getBool("PDF_HYPERLINKS"))
   {
     t << "\\hyperlink{";
     if (f) t << stripPath(f);
@@ -987,7 +997,7 @@ void LatexGenerator::endTextLink()
 void LatexGenerator::writeObjectLink(const char *ref, const char *f,
                                      const char *anchor, const char *text)
 {
-  if (!ref && Config_getBool("PDF_HYPERLINKS"))
+  if (!disableLinks && !ref && Config_getBool("PDF_HYPERLINKS"))
   {
     t << "\\hyperlink{";
     if (f) t << stripPath(f);
@@ -999,7 +1009,7 @@ void LatexGenerator::writeObjectLink(const char *ref, const char *f,
   }
   else
   {
-    t << "\\bf{";
+    t << "{\\bf ";
     docify(text);
     t << "}";
   } 
@@ -1007,7 +1017,7 @@ void LatexGenerator::writeObjectLink(const char *ref, const char *f,
 
 void LatexGenerator::startPageRef()
 {
-  t << " \\doxyref{";
+  t << " \\doxyref{}{";
 }
 
 void LatexGenerator::endPageRef(const char *clname, const char *anchor)
@@ -1019,7 +1029,8 @@ void LatexGenerator::endPageRef(const char *clname, const char *anchor)
 }
 
 void LatexGenerator::writeCodeLink(const char *,const char *,
-                                   const char *,const char *name)
+                                   const char *,const char *name,
+                                   const char *)
 {
   t << name;
   col+=strlen(name);
@@ -1079,10 +1090,12 @@ void LatexGenerator::startGroupHeader()
   {
     t << "\\subsection{";
   }
+  disableLinks=TRUE;
 }
 
 void LatexGenerator::endGroupHeader()
 {
+  disableLinks=FALSE;
   t << "}" << endl;
 }
 
@@ -1096,10 +1109,12 @@ void LatexGenerator::startMemberHeader()
   {
     t << "\\subsection*{";
   }
+  disableLinks=TRUE;
 }
 
 void LatexGenerator::endMemberHeader()
 {
+  disableLinks=FALSE;
   t << "}" << endl;
 }
 
@@ -1133,18 +1148,19 @@ void LatexGenerator::startMemberDoc(const char *clname,
     t << "}" << endl;
   }
   if (Config_getBool("COMPACT_LATEX")) t << "\\paragraph"; else t << "\\subsubsection";
-  if (Config_getBool("PDF_HYPERLINKS") && memname) 
-  {
-    t << "["; 
-    escapeMakeIndexChars(this,t,memname);
-    //filterTitle(title) 
-    t << "]";
-  }
+  //if (Config_getBool("PDF_HYPERLINKS") && memname) 
+  //{
+  //  t << "["; 
+  //  escapeMakeIndexChars(this,t,memname);
+  //  t << "]";
+  //}
   t << "{\\setlength{\\rightskip}{0pt plus 5cm}";
+  disableLinks=TRUE;
 }
 
 void LatexGenerator::endMemberDoc(bool) 
 { 
+  disableLinks=FALSE;
   t << "}";
   if (Config_getBool("COMPACT_LATEX")) t << "\\hfill";
 }
@@ -1343,12 +1359,29 @@ void LatexGenerator::endAnonTypeScope(int indent)
   }
 }
 
-void LatexGenerator::startMemberItem(int) 
+void LatexGenerator::startMemberTemplateParams()
+{
+  if (templateMemberItem)
+  {
+    t << "{\\footnotesize ";
+  }
+}
+
+void LatexGenerator::endMemberTemplateParams()
+{
+  if (templateMemberItem)
+  {
+    t << "}\\\\";
+  }
+}
+
+void LatexGenerator::startMemberItem(int annoType) 
 { 
   //printf("LatexGenerator::startMemberItem(%d)\n",annType);
   if (!insideTabbing)
   {
     t << "\\item " << endl; 
+    templateMemberItem = (annoType == 3);
   }
 }
 
@@ -1358,6 +1391,7 @@ void LatexGenerator::endMemberItem()
   {
     t << "\\\\";
  } 
+  templateMemberItem = FALSE;
   t << endl; 
 }
 
