@@ -2,7 +2,7 @@
  *
  * $Id: htmlgen.cpp,v 1.17 1998/11/28 11:33:19 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -184,8 +184,11 @@ void ManGenerator::writeString(const char *text)
   docify(text);
 }
 
-void ManGenerator::writeIndexItem(const char *,const char *,
-                                   const char *)
+void ManGenerator::startIndexItem(const char *,const char *)
+{
+}
+
+void ManGenerator::endIndexItem(const char *,const char *)
 {
 }
 
@@ -201,7 +204,8 @@ void ManGenerator::writeObjectLink(const char *,const char *,
 }
 
 void ManGenerator::writeCodeLink(const char *,const char *,
-                                    const char *, const char *name)
+                                 const char *, const char *name,
+                                 const char *)
 {
   docify(name);
 }
