@@ -2,7 +2,7 @@
  *
  * $Id: htmlgen.h,v 1.15 1998/11/28 11:33:19 root Exp $
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -74,13 +74,15 @@ class ManGenerator : public OutputGenerator
     //void startAlphabeticalIndexList() {}
     //void endAlphabeticalIndexList() {} 
     //void writeIndexHeading(const char *) {}
-    void writeIndexItem(const char *ref,const char *file,const char *name);
+    void startIndexItem(const char *ref,const char *file);
+    void endIndexItem(const char *ref,const char *file);
     void docify(const char *text);
     void codify(const char *text);
     void writeObjectLink(const char *ref,const char *file,
                          const char *anchor,const char *name);
     void writeCodeLink(const char *ref,const char *file,
-                       const char *anchor,const char *name);
+                       const char *anchor,const char *name,
+                       const char *tooltip);
     void startTextLink(const char *,const char *) {}
     void endTextLink() {}
     void startHtmlLink(const char *url);
@@ -267,6 +269,7 @@ class ManGenerator : public OutputGenerator
     //void endSectionRefList() {}
 
     void writeCodeAnchor(const char *) {}
+    void linkableSymbol(int,const char *,Definition *,Definition *) {}
 
   private:
     bool firstCol;
