@@ -2,7 +2,7 @@
  *
  * $Id: outputgen.h,v 1.48 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -36,6 +36,7 @@ class DotGroupCollaboration;
 class DocNode;
 class MemberDef;
 class GroupDef;
+class Definition;
 
 /*! \brief Output interface for code parser. 
  */
@@ -50,15 +51,17 @@ class CodeOutputInterface
     virtual void codify(const char *s) = 0;
 
     /*! Writes a link to an object in a code fragment.
-     *  \param ref    If this is non-zero, the object is to be found in
-     *                an external documentation file.
-     *  \param file   The file in which the object is located.
-     *  \param anchor The anchor uniquely identifying the object within 
-     *                the file. 
-     *  \param name   The text to display as a placeholder for the link.
+     *  \param ref      If this is non-zero, the object is to be found in
+     *                  an external documentation file.
+     *  \param file     The file in which the object is located.
+     *  \param anchor   The anchor uniquely identifying the object within 
+     *                  the file. 
+     *  \param name     The text to display as a placeholder for the link.
+     *  \param tooltip  The tooltip to display when the mouse is on the link.
      */
     virtual void writeCodeLink(const char *ref,const char *file,
-                               const char *anchor,const char *name) = 0;
+                               const char *anchor,const char *name,
+                               const char *tooltip) = 0;
 
     virtual void writeLineNumber(const char *ref,const char *file,
                                  const char *anchor,int lineNumber) = 0;
@@ -69,6 +72,8 @@ class CodeOutputInterface
     virtual void startFontClass(const char *) = 0;
     virtual void endFontClass() = 0;
     virtual void writeCodeAnchor(const char *name) = 0;
+    virtual void linkableSymbol(int line,const char *symName,
+                 Definition *symDef,Definition *context) = 0;
 };
 
 /*! \brief Base Interface used for generating output outside of the
@@ -273,6 +278,8 @@ class OutputGenerator : public BaseOutputDocInterface
     bool isEnabled() const { return active; }
     void pushGeneratorState();
     void popGeneratorState();
+    void setEncoding(const QCString &enc) { encoding = enc; }
+    virtual void postProcess(QByteArray &) { }
 
     virtual void printDoc(DocNode *,const char *langExt) = 0;
 
@@ -296,8 +303,8 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endIndexKey()   = 0;
     virtual void startIndexValue(bool) = 0;
     virtual void endIndexValue(const char *,bool) = 0;
-    virtual void writeIndexItem(const char *ref,const char *file,
-                                const char *text) = 0;
+    virtual void startIndexItem(const char *ref,const char *file) = 0;
+    virtual void endIndexItem(const char *ref,const char *file) = 0;
     virtual void startGroupHeader() = 0;
     virtual void endGroupHeader() = 0;
     virtual void startMemberSections() = 0;
@@ -306,8 +313,10 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endMemberHeader() = 0;
     virtual void startMemberSubtitle() = 0;
     virtual void endMemberSubtitle() = 0;
-    virtual void startMemberList()  = 0;
-    virtual void endMemberList()    = 0;
+    virtual void startMemberDocList() = 0;
+    virtual void endMemberDocList() = 0;
+    virtual void startMemberList() = 0;
+    virtual void endMemberList() = 0;
     virtual void startAnonTypeScope(int) = 0;
     virtual void endAnonTypeScope(int) = 0;
     virtual void startMemberItem(int) = 0;
@@ -376,6 +385,7 @@ class OutputGenerator : public BaseOutputDocInterface
     QCString dir;
     bool active;
     QStack<bool> *genStack;
+    QString encoding;
 
   private:
     OutputGenerator(const OutputGenerator &o);
