@@ -2,7 +2,7 @@
  *
  * $Id: outputlist.h,v 1.47 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -115,8 +115,10 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startItemList); }
     void endItemList() 
     { forall(&OutputGenerator::endItemList); }
-    void writeIndexItem(const char *ref,const char *file,const char *text)
-    { forall(&OutputGenerator::writeIndexItem,ref,file,text); }
+    void startIndexItem(const char *ref,const char *file)
+    { forall(&OutputGenerator::startIndexItem,ref,file); }
+    void endIndexItem(const char *ref,const char *file)
+    { forall(&OutputGenerator::endIndexItem,ref,file); }
     void docify(const char *s)
     { forall(&OutputGenerator::docify,s); }
     void codify(const char *s)
@@ -125,8 +127,9 @@ class OutputList : public OutputDocInterface
                          const char *anchor, const char *name)
     { forall(&OutputGenerator::writeObjectLink,ref,file,anchor,name); }
     void writeCodeLink(const char *ref,const char *file,
-                       const char *anchor,const char *name)
-    { forall(&OutputGenerator::writeCodeLink,ref,file,anchor,name); }
+                       const char *anchor,const char *name,
+                       const char *tooltip)
+    { forall(&OutputGenerator::writeCodeLink,ref,file,anchor,name,tooltip); }
     void startTextLink(const char *file,const char *anchor)
     { forall(&OutputGenerator::startTextLink,file,anchor); }
     void endTextLink()
@@ -162,6 +165,10 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startMemberSubtitle); }
     void endMemberSubtitle()
     { forall(&OutputGenerator::endMemberSubtitle); }
+    void startMemberDocList() 
+    { forall(&OutputGenerator::startMemberDocList); }
+    void endMemberDocList() 
+    { forall(&OutputGenerator::endMemberDocList); }
     void startMemberList() 
     { forall(&OutputGenerator::startMemberList); }
     void endMemberList() 
@@ -387,6 +394,7 @@ class OutputList : public OutputDocInterface
         og=outputs->next();
       }
     }
+    void linkableSymbol(int,const char *,Definition *,Definition *) {}
 
   private:
     void debug();
