@@ -3,7 +3,7 @@
  *
  *
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  * Authors: Dimitri van Heesch, Miguel Lobo.
  *
  * Permission to use, copy, modify, and distribute this software and its
@@ -629,6 +629,7 @@ void PerlModDocVisitor::visit(DocVerbatim *s)
   case DocVerbatim::LatexOnly:	type = "latexonly"; break;
   case DocVerbatim::XmlOnly:	type = "xmlonly"; break;
   case DocVerbatim::Dot:	type = "dot"; break;
+  case DocVerbatim::Msc:	type = "msc"; break;
   }
   openItem(type);
   m_output.addFieldQuotedString("content", s->text());
@@ -1440,16 +1441,16 @@ void PerlModGenerator::generatePerlModForMember(MemberDef *md,Definition *)
       md->memberType()!=MemberDef::Enumeration)
     m_output.addFieldQuotedString("type", md->typeString());
   
+  LockingPtr<ArgumentList> al = md->argumentList();
   if (isFunc) //function
   {
-    ArgumentList *al = md->argumentList();
-    m_output.addFieldBoolean("const", al && al->constSpecifier)
-      .addFieldBoolean("volatile", al && al->volatileSpecifier);
+    m_output.addFieldBoolean("const", al!=0 && al->constSpecifier)
+      .addFieldBoolean("volatile", al!=0 && al->volatileSpecifier);
 
     m_output.openList("parameters");
-    ArgumentList *declAl = md->declArgumentList();
-    ArgumentList *defAl = md->argumentList();
-    if (declAl && declAl->count()>0)
+    LockingPtr<ArgumentList> declAl = md->declArgumentList();
+    LockingPtr<ArgumentList> defAl  = md->argumentList();
+    if (declAl!=0 && declAl->count()>0)
     {
       ArgumentListIterator declAli(*declAl);
       ArgumentListIterator defAli(*defAl);
@@ -1487,7 +1488,7 @@ void PerlModGenerator::generatePerlModForMember(MemberDef *md,Definition *)
 	   md->argsString()!=0) // define
   {
     m_output.openList("parameters");
-    ArgumentListIterator ali(*md->argumentList());
+    ArgumentListIterator ali(*al);
     Argument *a;
     for (ali.toFirst();(a=ali.current());++ali)
     {
@@ -1505,10 +1506,11 @@ void PerlModGenerator::generatePerlModForMember(MemberDef *md,Definition *)
   
   if (md->memberType()==MemberDef::Enumeration) // enum
   {
-    if (md->enumFieldList())
+    LockingPtr<MemberList> enumFields = md->enumFieldList();
+    if (enumFields!=0)
     {
       m_output.openList("values");
-      MemberListIterator emli(*md->enumFieldList());
+      MemberListIterator emli(*enumFields);
       MemberDef *emd;
       for (emli.toFirst();(emd=emli.current());++emli)
       {
@@ -1534,8 +1536,8 @@ void PerlModGenerator::generatePerlModForMember(MemberDef *md,Definition *)
       .addFieldQuotedString("name", rmd->name())
       .closeHash();
 
-  MemberList *rbml = md->reimplementedBy();
-  if (rbml)
+  LockingPtr<MemberList> rbml = md->reimplementedBy();
+  if (rbml!=0)
   {
     MemberListIterator mli(*rbml);
     m_output.openList("reimplemented_by");
@@ -1552,7 +1554,7 @@ void PerlModGenerator::generatePerlModForMember(MemberDef *md,Definition *)
 void PerlModGenerator::generatePerlModSection(Definition *d,
 					      MemberList *ml,const char *name,const char *header)
 {
-  if (ml->count()==0) return; // empty list
+  if (ml==0) return; // empty list
 
   m_output.openHash(name);
 
@@ -1573,29 +1575,32 @@ void PerlModGenerator::generatePerlModSection(Definition *d,
 void PerlModGenerator::addListOfAllMembers(ClassDef *cd)
 {
   m_output.openList("all_members");
-  MemberNameInfoSDict::Iterator mnii(*cd->memberNameInfoSDict());
-  MemberNameInfo *mni;
-  for (mnii.toFirst();(mni=mnii.current());++mnii)
+  if (cd->memberNameInfoSDict())
   {
-    MemberNameInfoIterator mii(*mni);
-    MemberInfo *mi;
-    for (mii.toFirst();(mi=mii.current());++mii)
+    MemberNameInfoSDict::Iterator mnii(*cd->memberNameInfoSDict());
+    MemberNameInfo *mni;
+    for (mnii.toFirst();(mni=mnii.current());++mnii)
     {
-      MemberDef *md=mi->memberDef;
-      ClassDef  *cd=md->getClassDef();
-      Definition *d=md->getGroupDef();
-      if (d==0) d = cd;
+      MemberNameInfoIterator mii(*mni);
+      MemberInfo *mi;
+      for (mii.toFirst();(mi=mii.current());++mii)
+      {
+        MemberDef *md=mi->memberDef;
+        ClassDef  *cd=md->getClassDef();
+        Definition *d=md->getGroupDef();
+        if (d==0) d = cd;
 
-      m_output.openHash()
-	.addFieldQuotedString("name", md->name())
-	.addFieldQuotedString("virtualness", getVirtualnessName(md->virtualness()))
-	.addFieldQuotedString("protection", getProtectionName(mi->prot));
+        m_output.openHash()
+          .addFieldQuotedString("name", md->name())
+          .addFieldQuotedString("virtualness", getVirtualnessName(md->virtualness()))
+          .addFieldQuotedString("protection", getProtectionName(mi->prot));
 
-      if (!mi->ambiguityResolutionScope.isEmpty())
-	m_output.addFieldQuotedString("ambiguity_scope", mi->ambiguityResolutionScope);
+        if (!mi->ambiguityResolutionScope.isEmpty())
+          m_output.addFieldQuotedString("ambiguity_scope", mi->ambiguityResolutionScope);
 
-      m_output.addFieldQuotedString("scope", cd->name())
-	.closeHash();
+        m_output.addFieldQuotedString("scope", cd->name())
+          .closeHash();
+      }
     }
   }
   m_output.closeList();
@@ -1626,7 +1631,7 @@ void PerlModGenerator::generatePerlModForClass(ClassDef *cd)
   m_output.openHash()
     .addFieldQuotedString("name", cd->name());
   
-  if (cd->baseClasses()->count()>0)
+  if (cd->baseClasses())
   {
     m_output.openList("base");
     BaseClassListIterator bcli(*cd->baseClasses());
@@ -1640,10 +1645,10 @@ void PerlModGenerator::generatePerlModForClass(ClassDef *cd)
     m_output.closeList();
   }
 
-  if (cd->subClasses()->count()>0)
+  if (cd->subClasses())
   {
     m_output.openList("derived");
-    BaseClassListIterator bcli(*cd->baseClasses());
+    BaseClassListIterator bcli(*cd->subClasses());
     BaseClassDef *bcd;
     for (bcli.toFirst();(bcd=bcli.current());++bcli)
       m_output.openHash()
@@ -1687,34 +1692,34 @@ void PerlModGenerator::generatePerlModForClass(ClassDef *cd)
 
   addTemplateList(cd,m_output);
   addListOfAllMembers(cd);
-  MemberGroupSDict::Iterator mgli(*cd->memberGroupSDict);
+  MemberGroupSDict::Iterator mgli(*cd->getMemberGroupSDict());
   MemberGroup *mg;
   for (;(mg=mgli.current());++mgli)
     generatePerlModSection(cd,mg->members(),"user_defined",mg->header());
 
-  generatePerlModSection(cd,&cd->pubTypes,"public_typedefs");
-  generatePerlModSection(cd,&cd->pubMethods,"public_methods");
-  generatePerlModSection(cd,&cd->pubAttribs,"public_members");
-  generatePerlModSection(cd,&cd->pubSlots,"public_slots");
-  generatePerlModSection(cd,&cd->signals,"signals");
-  generatePerlModSection(cd,&cd->dcopMethods,"dcop_methods");
-  generatePerlModSection(cd,&cd->properties,"properties");
-  generatePerlModSection(cd,&cd->pubStaticMethods,"public_static_methods");
-  generatePerlModSection(cd,&cd->pubStaticAttribs,"public_static_members");
-  generatePerlModSection(cd,&cd->proTypes,"protected_typedefs");
-  generatePerlModSection(cd,&cd->proMethods,"protected_methods");
-  generatePerlModSection(cd,&cd->proAttribs,"protected_members");
-  generatePerlModSection(cd,&cd->proSlots,"protected_slots");
-  generatePerlModSection(cd,&cd->proStaticMethods,"protected_static_methods");
-  generatePerlModSection(cd,&cd->proStaticAttribs,"protected_static_members");
-  generatePerlModSection(cd,&cd->priTypes,"private_typedefs");
-  generatePerlModSection(cd,&cd->priMethods,"private_methods");
-  generatePerlModSection(cd,&cd->priAttribs,"private_members");
-  generatePerlModSection(cd,&cd->priSlots,"private_slots");
-  generatePerlModSection(cd,&cd->priStaticMethods,"private_static_methods");
-  generatePerlModSection(cd,&cd->priStaticAttribs,"private_static_members");
-  generatePerlModSection(cd,&cd->friends,"friend_methods");
-  generatePerlModSection(cd,&cd->related,"related_methods");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::pubTypes),"public_typedefs");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::pubMethods),"public_methods");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::pubAttribs),"public_members");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::pubSlots),"public_slots");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::signals),"signals");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::dcopMethods),"dcop_methods");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::properties),"properties");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::pubStaticMethods),"public_static_methods");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::pubStaticAttribs),"public_static_members");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::proTypes),"protected_typedefs");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::proMethods),"protected_methods");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::proAttribs),"protected_members");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::proSlots),"protected_slots");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::proStaticMethods),"protected_static_methods");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::proStaticAttribs),"protected_static_members");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::priTypes),"private_typedefs");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::priMethods),"private_methods");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::priAttribs),"private_members");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::priSlots),"private_slots");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::priStaticMethods),"private_static_methods");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::priStaticAttribs),"private_static_members");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::friends),"friend_methods");
+  generatePerlModSection(cd,cd->getMemberList(MemberList::related),"related_methods");
 
   addPerlModDocBlock(m_output,"brief",cd->getDefFileName(),cd->getDefLine(),cd,0,cd->briefDescription());
   addPerlModDocBlock(m_output,"detailed",cd->getDefFileName(),cd->getDefLine(),cd,0,cd->documentation());
@@ -1764,7 +1769,7 @@ void PerlModGenerator::generatePerlModForNamespace(NamespaceDef *nd)
   m_output.openHash()
     .addFieldQuotedString("name", nd->name());
   
-  ClassSDict *cl = nd->classSDict;
+  ClassSDict *cl = nd->getClassSDict();
   if (cl)
   {
     m_output.openList("classes");
@@ -1777,7 +1782,7 @@ void PerlModGenerator::generatePerlModForNamespace(NamespaceDef *nd)
     m_output.closeList();
   }
 
-  NamespaceSDict *nl = nd->namespaceSDict;
+  NamespaceSDict *nl = nd->getNamespaceSDict();
   if (nl)
   {
     m_output.openList("namespaces");
@@ -1790,17 +1795,17 @@ void PerlModGenerator::generatePerlModForNamespace(NamespaceDef *nd)
     m_output.closeList();
   }
 
-  MemberGroupSDict::Iterator mgli(*nd->memberGroupSDict);
+  MemberGroupSDict::Iterator mgli(*nd->getMemberGroupSDict());
   MemberGroup *mg;
   for (;(mg=mgli.current());++mgli)
     generatePerlModSection(nd,mg->members(),"user-defined",mg->header());
 
-  generatePerlModSection(nd,&nd->decDefineMembers,"defines");
-  generatePerlModSection(nd,&nd->decProtoMembers,"prototypes");
-  generatePerlModSection(nd,&nd->decTypedefMembers,"typedefs");
-  generatePerlModSection(nd,&nd->decEnumMembers,"enums");
-  generatePerlModSection(nd,&nd->decFuncMembers,"functions");
-  generatePerlModSection(nd,&nd->decVarMembers,"variables");
+  generatePerlModSection(nd,nd->getMemberList(MemberList::decDefineMembers),"defines");
+  generatePerlModSection(nd,nd->getMemberList(MemberList::decProtoMembers),"prototypes");
+  generatePerlModSection(nd,nd->getMemberList(MemberList::decTypedefMembers),"typedefs");
+  generatePerlModSection(nd,nd->getMemberList(MemberList::decEnumMembers),"enums");
+  generatePerlModSection(nd,nd->getMemberList(MemberList::decFuncMembers),"functions");
+  generatePerlModSection(nd,nd->getMemberList(MemberList::decVarMembers),"variables");
 
   addPerlModDocBlock(m_output,"brief",nd->getDefFileName(),nd->getDefLine(),0,0,nd->briefDescription());
   addPerlModDocBlock(m_output,"detailed",nd->getDefFileName(),nd->getDefLine(),0,0,nd->documentation());
@@ -1829,41 +1834,47 @@ void PerlModGenerator::generatePerlModForFile(FileDef *fd)
   m_output.openHash()
     .addFieldQuotedString("name", fd->name());
   
-  QListIterator<IncludeInfo> ili1(*fd->includeFileList());
   IncludeInfo *inc;
   m_output.openList("includes");
-  for (ili1.toFirst();(inc=ili1.current());++ili1)
+  if (fd->includeFileList())
   {
-    m_output.openHash()
-      .addFieldQuotedString("name", inc->includeName);
-    if (inc->fileDef && !inc->fileDef->isReference())
+    QListIterator<IncludeInfo> ili1(*fd->includeFileList());
+    for (ili1.toFirst();(inc=ili1.current());++ili1)
     {
-      m_output.addFieldQuotedString("ref", inc->fileDef->getOutputFileBase());
+      m_output.openHash()
+        .addFieldQuotedString("name", inc->includeName);
+      if (inc->fileDef && !inc->fileDef->isReference())
+      {
+        m_output.addFieldQuotedString("ref", inc->fileDef->getOutputFileBase());
+      }
+      m_output.closeHash();
     }
-    m_output.closeHash();
   }
   m_output.closeList();
   
-  QListIterator<IncludeInfo> ili2(*fd->includedByFileList());
   m_output.openList("included_by");
-  for (ili2.toFirst();(inc=ili2.current());++ili2)
+  if (fd->includedByFileList())
   {
-    m_output.openHash()
-      .addFieldQuotedString("name", inc->includeName);
-    if (inc->fileDef && !inc->fileDef->isReference())
+    QListIterator<IncludeInfo> ili2(*fd->includedByFileList());
+    for (ili2.toFirst();(inc=ili2.current());++ili2)
     {
-      m_output.addFieldQuotedString("ref", inc->fileDef->getOutputFileBase());
+      m_output.openHash()
+        .addFieldQuotedString("name", inc->includeName);
+      if (inc->fileDef && !inc->fileDef->isReference())
+      {
+        m_output.addFieldQuotedString("ref", inc->fileDef->getOutputFileBase());
+      }
+      m_output.closeHash();
     }
-    m_output.closeHash();
   }
   m_output.closeList();
   
-  generatePerlModSection(fd,&fd->decDefineMembers,"defines");
-  generatePerlModSection(fd,&fd->decProtoMembers,"prototypes");
-  generatePerlModSection(fd,&fd->decTypedefMembers,"typedefs");
-  generatePerlModSection(fd,&fd->decEnumMembers,"enums");
-  generatePerlModSection(fd,&fd->decFuncMembers,"functions");
-  generatePerlModSection(fd,&fd->decVarMembers,"variables");
+  generatePerlModSection(fd,fd->getMemberList(MemberList::decDefineMembers),"defines");
+  generatePerlModSection(fd,fd->getMemberList(MemberList::decProtoMembers),"prototypes");
+  generatePerlModSection(fd,fd->getMemberList(MemberList::decTypedefMembers),"typedefs");
+  generatePerlModSection(fd,fd->getMemberList(MemberList::decEnumMembers),"enums");
+  generatePerlModSection(fd,fd->getMemberList(MemberList::decFuncMembers),"functions");
+  generatePerlModSection(fd,fd->getMemberList(MemberList::decVarMembers),"variables");
 
   addPerlModDocBlock(m_output,"brief",fd->getDefFileName(),fd->getDefLine(),0,0,fd->briefDescription());
   addPerlModDocBlock(m_output,"detailed",fd->getDefFileName(),fd->getDefLine(),0,0,fd->documentation());
@@ -1956,17 +1967,17 @@ void PerlModGenerator::generatePerlModForGroup(GroupDef *gd)
     m_output.closeList();
   }
 
-  MemberGroupSDict::Iterator mgli(*gd->memberGroupSDict);
+  MemberGroupSDict::Iterator mgli(*gd->getMemberGroupSDict());
   MemberGroup *mg;
   for (;(mg=mgli.current());++mgli)
     generatePerlModSection(gd,mg->members(),"user-defined",mg->header());
 
-  generatePerlModSection(gd,&gd->decDefineMembers,"defines");
-  generatePerlModSection(gd,&gd->decProtoMembers,"prototypes");
-  generatePerlModSection(gd,&gd->decTypedefMembers,"typedefs");
-  generatePerlModSection(gd,&gd->decEnumMembers,"enums");
-  generatePerlModSection(gd,&gd->decFuncMembers,"functions");
-  generatePerlModSection(gd,&gd->decVarMembers,"variables");
+  generatePerlModSection(gd,gd->getMemberList(MemberList::decDefineMembers),"defines");
+  generatePerlModSection(gd,gd->getMemberList(MemberList::decProtoMembers),"prototypes");
+  generatePerlModSection(gd,gd->getMemberList(MemberList::decTypedefMembers),"typedefs");
+  generatePerlModSection(gd,gd->getMemberList(MemberList::decEnumMembers),"enums");
+  generatePerlModSection(gd,gd->getMemberList(MemberList::decFuncMembers),"functions");
+  generatePerlModSection(gd,gd->getMemberList(MemberList::decVarMembers),"variables");
 
   addPerlModDocBlock(m_output,"brief",gd->getDefFileName(),gd->getDefLine(),0,0,gd->briefDescription());
   addPerlModDocBlock(m_output,"detailed",gd->getDefFileName(),gd->getDefLine(),0,0,gd->documentation());
@@ -2005,21 +2016,21 @@ bool PerlModGenerator::generatePerlModOutput()
   m_output.add("$doxydocs=").openHash();
   
   m_output.openList("classes");
-  ClassSDict::Iterator cli(Doxygen::classSDict);
+  ClassSDict::Iterator cli(*Doxygen::classSDict);
   ClassDef *cd;
   for (cli.toFirst();(cd=cli.current());++cli)
     generatePerlModForClass(cd);
   m_output.closeList();
 
   m_output.openList("namespaces");
-  NamespaceSDict::Iterator nli(Doxygen::namespaceSDict);
+  NamespaceSDict::Iterator nli(*Doxygen::namespaceSDict);
   NamespaceDef *nd;
   for (nli.toFirst();(nd=nli.current());++nli)
     generatePerlModForNamespace(nd);
   m_output.closeList();
 
   m_output.openList("files");
-  FileNameListIterator fnli(Doxygen::inputNameList);
+  FileNameListIterator fnli(*Doxygen::inputNameList);
   FileName *fn;
   for (;(fn=fnli.current());++fnli)
   {
@@ -2031,7 +2042,7 @@ bool PerlModGenerator::generatePerlModOutput()
   m_output.closeList();
 
   m_output.openList("groups");
-  GroupSDict::Iterator gli(Doxygen::groupSDict);
+  GroupSDict::Iterator gli(*Doxygen::groupSDict);
   GroupDef *gd;
   for (;(gd=gli.current());++gli)
   {
