@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -151,6 +151,7 @@ class PrintDocVisitor : public DocVisitor
         case DocVerbatim::LatexOnly: printf("<latexonly>"); break;
         case DocVerbatim::XmlOnly: printf("<xmlonly>"); break;
         case DocVerbatim::Dot: printf("<dot>"); break;
+        case DocVerbatim::Msc: printf("<msc>"); break;
       }
       printf("%s",s->text().data());
       switch(s->type())
@@ -162,6 +163,7 @@ class PrintDocVisitor : public DocVisitor
         case DocVerbatim::LatexOnly: printf("</latexonly>"); break;
         case DocVerbatim::XmlOnly: printf("</xmlonly>"); break;
         case DocVerbatim::Dot: printf("</dot>"); break;
+        case DocVerbatim::Msc: printf("</msc>"); break;
       }
     }
     void visit(DocAnchor *a)
