@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -27,10 +27,11 @@
 #include "message.h"
 #include <qfileinfo.h> 
 #include "parserintf.h"
+#include "msc.h"
 
 
-#define DBG_RTF(x) m_t << x
-//#define DBG_RTF(x) do {} while(0)
+//#define DBG_RTF(x) m_t << x
+#define DBG_RTF(x) do {} while(0)
 
 RTFDocVisitor::RTFDocVisitor(QTextStream &t,CodeOutputInterface &ci,
                              const char *langExt) 
@@ -354,9 +355,10 @@ void RTFDocVisitor::visit(DocVerbatim *s)
         static int dotindex = 1;
         QCString fileName(4096);
 
-        fileName.sprintf("%s%d", 
+        fileName.sprintf("%s%d%s", 
             (Config_getString("RTF_OUTPUT")+"/inline_dotgraph_").data(), 
-            dotindex++
+            dotindex++,
+            ".dot"
            );
         QFile file(fileName);
         if (!file.open(IO_WriteOnly))
@@ -368,7 +370,32 @@ void RTFDocVisitor::visit(DocVerbatim *s)
         m_t << "\\par{\\qc "; // center picture
         writeDotFile(fileName);
         m_t << "} ";
-        file.remove();
+        if (Config_getBool("DOT_CLEANUP")) file.remove();
+      }
+      break;
+    case DocVerbatim::Msc: 
+      {
+        static int mscindex = 1;
+        QCString baseName(4096);
+
+        baseName.sprintf("%s%d", 
+            (Config_getString("RTF_OUTPUT")+"/inline_mscgraph_").data(), 
+            mscindex++
+           );
+        QFile file(baseName+".msc");
+        if (!file.open(IO_WriteOnly))
+        {
+          err("Could not open file %s for writing\n",baseName.data());
+        }
+        QCString text = "msc {";
+        text+=s->text();
+        text+="}";
+        file.writeBlock( text, text.length() );
+        file.close();
+        m_t << "\\par{\\qc "; // center picture
+        writeMscFile(baseName);
+        m_t << "} ";
+        if (Config_getBool("DOT_CLEANUP")) file.remove();
       }
       break;
   }
@@ -1293,12 +1320,12 @@ void RTFDocVisitor::visitPost(DocText *)
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocText)}\n");
 }
 
-static char* getMultiByte(int c)
-{
-    static char s[10];
-    sprintf(s,"\\'%X",c);
-    return s;
-}
+//static char* getMultiByte(int c)
+//{
+//    static char s[10];
+//    sprintf(s,"\\'%X",c);
+//    return s;
+//}
 
 void RTFDocVisitor::filter(const char *str,bool verbatim)
 { 
@@ -1309,21 +1336,21 @@ void RTFDocVisitor::filter(const char *str,bool verbatim)
     unsigned char pc='\0';
     while (*p)
     {
-      static bool MultiByte = FALSE;
+      //static bool MultiByte = FALSE;
       c=*p++;
 
-      if ( MultiByte )
-      {
-        m_t << getMultiByte( c );
-        MultiByte = FALSE;
-        continue;
-      }
-      if ( c >= 0x80 )
-      {
-        MultiByte = TRUE;
-        m_t << getMultiByte( c );
-        continue;
-      }
+      //if ( MultiByte )
+      //{
+      //  m_t << getMultiByte( c );
+      //  MultiByte = FALSE;
+      //  continue;
+      //}
+      //if ( c >= 0x80 )
+      //{
+      //  MultiByte = TRUE;
+      //  m_t << getMultiByte( c );
+      //  continue;
+      //}
 
       switch (c)
       {
@@ -1419,4 +1446,23 @@ void RTFDocVisitor::writeDotFile(const QString &fileName)
   m_lastIsPara=TRUE;
 }
 
+void RTFDocVisitor::writeMscFile(const QString &fileName)
+{
+  QString baseName=fileName;
+  int i;
+  if ((i=baseName.findRev('/'))!=-1)
+  {
+    baseName=baseName.right(baseName.length()-i-1);
+  } 
+  QString outDir = Config_getString("RTF_OUTPUT");
+  writeMscGraphFromFile(fileName,outDir,baseName,MSC_BITMAP);
+  if (!m_lastIsPara) m_t << "\\par" << endl;
+  m_t << "{" << endl;
+  m_t << rtf_Style_Reset;
+  m_t << "\\pard \\qc {\\field\\flddirty {\\*\\fldinst INCLUDEPICTURE \"";
+  m_t << baseName << ".png";
+  m_t << "\" \\\\d \\\\*MERGEFORMAT}{\\fldrslt IMAGE}}\\par" << endl;
+  m_t << "}" << endl;
+  m_lastIsPara=TRUE;
+}
 
