@@ -2,7 +2,7 @@
  *
  * $Id: rtfgen.h,v 1.13 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2006 by Parker Waechter & Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Parker Waechter & Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -49,6 +49,7 @@ class RTFGenerator : public OutputGenerator
     void writeFooter() {}
     void endFile();
     void clearBuffer();
+    void postProcess(QByteArray &);
     
     //void writeIndex();
 	
@@ -72,23 +73,19 @@ class RTFGenerator : public OutputGenerator
     void endIndexValue(const char *,bool);
     void startItemList();
     void endItemList();
-    //void startEnumList();
-    //void endEnumList();
-    //void startAlphabeticalIndexList() {}
-    //void endAlphabeticalIndexList() {} 
-    //void writeIndexHeading(const char *) {}
-    void writeIndexItem(const char *ref,const char *file,const char *name);
+    void startIndexItem(const char *ref,const char *file);
+    void endIndexItem(const char *ref,const char *file);
     void docify(const char *text);
     void codify(const char *text);
     void writeObjectLink(const char *ref,const char *file,
                          const char *anchor,const char *name);
     void writeCodeLink(const char *ref, const char *file,
-                       const char *anchor,const char *name);
+                       const char *anchor,const char *name,
+                       const char *tooltip);
     void startTextLink(const char *f,const char *anchor);
     void endTextLink();
     void startHtmlLink(const char *url);
     void endHtmlLink();
-    //void writeMailLink(const char *url);
     void startTypewriter() { t << "{\\f2 "; }
     void endTypewriter()   { t << "}";      }
     void startGroupHeader();
@@ -270,6 +267,7 @@ class RTFGenerator : public OutputGenerator
     //void endSectionRefList() {}
 
     void writeCodeAnchor(const char *) {}
+    void linkableSymbol(int,const char *,Definition *,Definition *) {}
 
     static bool preProcessFileInplace(const char *path,const char *name);
     
@@ -301,7 +299,7 @@ class RTFGenerator : public OutputGenerator
     void rtfwriteRuler_thick();
     void rtfwriteRuler_thin();
     void writeRTFReference(const char *label);
-    char *getMultiByte(int c);
+    //char *getMultiByte(int c);
 };
 
 #endif
