@@ -2,7 +2,7 @@
  *
  * $Id: scanner.h,v 1.15 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -29,6 +29,7 @@
 class CLanguageScanner : public ParserInterface
 {
   public:
+    virtual ~CLanguageScanner() {}
     void parseInput(const char *fileName,
                     const char *fileBuf,
                     Entry *root);
@@ -48,4 +49,6 @@ class CLanguageScanner : public ParserInterface
     void parsePrototype(const char *text);
 };
 
+void scanFreeScanner();
+
 #endif
