@@ -3,7 +3,7 @@
  * $Id: tagreader.cpp,v 1.2 2001/03/19 19:27:41 root Exp $
  *
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -1169,15 +1169,16 @@ void TagFileParser::buildLists(Entry *root)
   while (tci)
   {
     Entry *ce = new Entry;
+    ce->section = Entry::CLASS_SEC;
     switch (tci->kind)
     {
-      case TagClassInfo::Class:     ce->section = Entry::CLASS_SEC;     break;
-      case TagClassInfo::Struct:    ce->section = Entry::STRUCT_SEC;    break;
-      case TagClassInfo::Union:     ce->section = Entry::UNION_SEC;     break;
-      case TagClassInfo::Interface: ce->section = Entry::INTERFACE_SEC; break;
-      case TagClassInfo::Exception: ce->section = Entry::EXCEPTION_SEC; break;
-      case TagClassInfo::Protocol:  ce->section = Entry::PROTOCOL_SEC;  break;
-      case TagClassInfo::Category:  ce->section = Entry::CATEGORY_SEC;  break;
+      case TagClassInfo::Class:     break;
+      case TagClassInfo::Struct:    ce->spec = Entry::Struct;    break;
+      case TagClassInfo::Union:     ce->spec = Entry::Union;     break;
+      case TagClassInfo::Interface: ce->spec = Entry::Interface; break;
+      case TagClassInfo::Exception: ce->spec = Entry::Exception; break;
+      case TagClassInfo::Protocol:  ce->spec = Entry::Protocol;  break;
+      case TagClassInfo::Category:  ce->spec = Entry::Category;  break;
     }
     ce->name     = tci->name;
     addDocAnchors(ce,tci->docAnchors);
@@ -1247,7 +1248,7 @@ void TagFileParser::buildLists(Entry *root)
     {
       mn = new FileName(fullName,tfi->name);
       mn->append(fd);
-      Doxygen::inputNameList.inSort(mn);
+      Doxygen::inputNameList->inSort(mn);
       Doxygen::inputNameDict->insert(tfi->name,mn);
     }
     buildMemberList(fe,tfi->members);
