@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -12,9 +12,12 @@
  *
  * Brazilian Portuguese version by
  *   Fabio "FJTC" Jun Takada Chino <jun-chino at uol.com.br>
- *   Version: 1.4.1 (2005/03/20)
+ *   Version: 1.4.6 (2006/06/26)
  *
  * History:
+ *	 1.4.6
+ *		- trCallerGraph() added.
+ *      - trEnumerationValueDocumentation() added.
  *   1.4.1
  *		- Method trOverloadText() added.
  * 	 1.3.9
@@ -36,7 +39,7 @@
 #ifndef TRANSLATOR_BR_H
 #define TRANSLATOR_BR_H
 
-class TranslatorBrazilian : public TranslatorAdapter_1_4_6
+class TranslatorBrazilian : public Translator
 {
   public:
 
@@ -61,7 +64,7 @@ class TranslatorBrazilian : public TranslatorAdapter_1_4_6
      */
     virtual QCString latexLanguageSupportCommand()
     {
-      return "";
+      return "\\usepackage[spanish]{babel}";
     }
 
     /*! return the language charset. This will be used for the HTML output */
@@ -180,10 +183,6 @@ class TranslatorBrazilian : public TranslatorAdapter_1_4_6
     virtual QCString trFileList()
     { return "Lista de Arquivos"; }
 
-    /*! This is put above each page as a link to the list of all verbatim headers */
-    virtual QCString trHeaderFiles()
-    { return "Arquivos de Cabealho (Headers)"; }
-
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     {
@@ -318,10 +317,6 @@ class TranslatorBrazilian : public TranslatorAdapter_1_4_6
       return result;
     }
 
-    /*! This is an introduction to the page with the list of all header files. */
-    virtual QCString trHeaderFilesDescription()
-    { return "Estes so os arquivos de cabealho que compe a API:"; }
-
     /*! This is an introduction to the page with the list of all examples */
     virtual QCString trExamplesDescription()
     { return "Esta  a lista com todos os exemplos:"; }
@@ -334,15 +329,6 @@ class TranslatorBrazilian : public TranslatorAdapter_1_4_6
     virtual QCString trModulesDescription()
     { return "Esta  a lista com todos os mdulos:"; }
 
-    /*! This sentences is used in the annotated class/file lists if no brief
-     * description is given.
-     */
-    virtual QCString trNoDescriptionAvailable()
-    { return "Sem descrio disponvel"; }
-
-    // index titles (the project name is prepended for these)
-
-
     /*! This is used in HTML as the title of index.html. */
     virtual QCString trDocumentation()
     { return "\nDocumentao"; }
@@ -489,12 +475,6 @@ class TranslatorBrazilian : public TranslatorAdapter_1_4_6
     virtual QCString trEnumerationTypeDocumentation()
     { return "Enumeraes"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
-     *  of documentation blocks for enumeration values
-     */
-    virtual QCString trEnumerationValueDocumentation()
-    { return "Valores enumerados"; }
-
     /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for functions
      */
@@ -549,18 +529,10 @@ class TranslatorBrazilian : public TranslatorAdapter_1_4_6
     virtual QCString trForInternalUseOnly()
     { return "Apenas para uso interno."; }
 
-    /*! this text is generated when the \\reimp command is used. */
-    virtual QCString trReimplementedForInternalReasons()
-    { return "Reimplementado por razes internas. A API no foi modificada."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Aviso"; }
 
-    /*! this text is generated when the \\bug command is used. */
-    virtual QCString trBugsAndLimitations()
-    { return "Problemas e Limitaes"; }
-
     /*! this text is generated when the \\version command is used. */
     virtual QCString trVersion()
     { return "Verso"; }
@@ -835,10 +807,6 @@ class TranslatorBrazilian : public TranslatorAdapter_1_4_6
 // new since 0.49-991003
 //////////////////////////////////////////////////////////////////////////
 
-    virtual QCString trSources()
-    {
-      return "Cdigos-Fonte";
-    }
     virtual QCString trDefinedAtLineInSourceFile()
     {
       return "Definio na linha @0 do arquivo @1.";
@@ -1048,6 +1016,8 @@ class TranslatorBrazilian : public TranslatorAdapter_1_4_6
         "class Undocumented { };\n\n"
         "/*! Class that is inherited using public inheritance */\n"
         "class PublicBase : public Truncated { };\n\n"
+        "/*! A template class */\n"
+        "template<class T> class Templ { };\n\n"
         "/*! Class that is inherited using protected inheritance */\n"
         "class ProtectedBase { };\n\n"
         "/*! Class that is inherited using private inheritance */\n"
@@ -1058,7 +1028,8 @@ class TranslatorBrazilian : public TranslatorAdapter_1_4_6
         "class Inherited : public PublicBase,\n"
         "                  protected ProtectedBase,\n"
         "                  private PrivateBase,\n"
-        "                  public Undocumented\n"
+        "                  public Undocumented,\n"
+        "                  public Templ<int>\n"
         "{\n"
         "  private:\n"
         "    Used *m_usedClass;\n"
@@ -1141,11 +1112,6 @@ class TranslatorBrazilian : public TranslatorAdapter_1_4_6
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    virtual QCString trInterfaces()
-    {
-      return "Interfaces";
-    }
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
@@ -1178,11 +1144,6 @@ class TranslatorBrazilian : public TranslatorAdapter_1_4_6
     {
       return "Pacotes";
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return "Pacotes";
-    }
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -1319,17 +1280,6 @@ class TranslatorBrazilian : public TranslatorAdapter_1_4_6
       return result;
     }
 
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names
-     *  of the category.
-     */
-    virtual QCString trField(bool first_capital, bool singular)
-    {
-      QCString result((first_capital ? "Campo" : "campo"));
-      if (!singular)  result+="s";
-      return result;
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names
      *  of the category.
@@ -1612,6 +1562,22 @@ class TranslatorBrazilian : public TranslatorAdapter_1_4_6
        		"Ele difere do mtodo acima apenas na lista de "
        		"argumentos que devem ser utilizados.";
     }    
-    
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.6
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used to introduce a caller (or called-by) graph */
+    virtual QCString trCallerGraph()
+    {
+      return "Este  o diagrama de chamadas para esta funo:";
+    }
+
+    /*! This is used in the documentation of a file/namespace before the list 
+     *  of documentation blocks for enumeration values
+     */
+    virtual QCString trEnumerationValueDocumentation()
+    { return "Documentao da enumerao"; }
+  
 };
 #endif
