@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -39,7 +39,7 @@
 // Translator class (by the local maintainer) when the localized
 // translator is made up-to-date again.
 
-class TranslatorCatalan : public TranslatorAdapter_1_4_6
+class TranslatorCatalan : public Translator
 {
   public:
 
@@ -70,7 +70,8 @@ class TranslatorCatalan : public TranslatorAdapter_1_4_6
      */
     virtual QCString latexLanguageSupportCommand()
     {
-      return "\\usepackage[catalan]{babel} \n\\usepackage[latin1]{inputenc}";
+      //return "\\usepackage[catalan]{babel}\n\\usepackage[latin1]{inputenc}";
+      return "\\usepackage[catalan]{babel}\n";
     }
 
     /*! return the language charset. This will be used for the HTML output */
@@ -1037,7 +1038,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_4_6
         "class Inherited : public PublicBase,\n"
         "                  protected ProtectedBase,\n"
         "                  private PrivateBase,\n"
-        "                  public Undocumented\n"
+        "                  public Undocumented,\n"
         "                  public Templ<int>\n"
         "{\n"
         "  private:\n"
@@ -1557,6 +1558,24 @@ class TranslatorCatalan : public TranslatorAdapter_1_4_6
               "proveda per convenincia. Es diferencia de la funci "
               "anterior noms en els arguments que accepta.";
     }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.6
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used to introduce a caller (or called-by) graph */
+    virtual QCString trCallerGraph()
+    {
+      return "Grfic de crides a aquesta funci:";
+    }
+
+    /*! This is used in the documentation of a file/namespace before the list 
+     *  of documentation blocks for enumeration values
+     */
+    virtual QCString trEnumerationValueDocumentation()
+    { return "Documentaci de les Enumeracions"; }
+
+
 };
 
 #endif
