@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -68,6 +68,7 @@
 // 2006/05/10 - Update for "new since 1.4.6" -- trCallerGraph(), 
 //              modified trCallGraph() to make the meaning unambiguous
 //              and clear in the Czech language.
+// 2006/06/13 - translation of the trEnumerationValueDocumentation().
 
 // Todo
 // ----
@@ -87,7 +88,7 @@
 // Windows version. The version which does not call the function is
 // probably slightly faster.
 
-class TranslatorCzech : public TranslatorAdapter_1_4_6
+class TranslatorCzech : public Translator
 {
   private:
     /*! The decode() inline assumes the source written in the 
@@ -95,14 +96,14 @@ class TranslatorCzech : public TranslatorAdapter_1_4_6
      */
     inline QCString decode(const QCString & sInput)
     { 
-      if (Config_getBool("USE_WINDOWS_ENCODING"))
-      {
+      //if (Config_getBool("USE_WINDOWS_ENCODING"))
+      //{
         return sInput;
-      }
-      else
-      {
-        return Win1250ToISO88592(sInput);
-      }
+      //}
+      //else
+      //{
+      //  return Win1250ToISO88592(sInput);
+      //}
     }
     
   public:
@@ -112,19 +113,22 @@ class TranslatorCzech : public TranslatorAdapter_1_4_6
     { return "czech"; }
 
     virtual QCString latexLanguageSupportCommand()
-    { return "\\usepackage{czech}\n"; }
+    { 
+      return "\\usepackage[T2A]{fontenc}\n"
+             "\\usepackage[czech]{babel}\n";
+    }
     
     /*! return the language charset. This will be used for the HTML output */
     virtual QCString idLanguageCharset()
     {
-      if (Config_getBool("USE_WINDOWS_ENCODING"))
-      {
+      //if (Config_getBool("USE_WINDOWS_ENCODING"))
+      //{
         return "windows-1250";
-      }
-      else
-      {
-        return "iso-8859-2";
-      }
+      //}
+      //else
+      //{
+      //  return "iso-8859-2";
+      //}
     }
 
     // --- Language translation methods -------------------
@@ -1634,6 +1638,13 @@ class TranslatorCzech : public TranslatorAdapter_1_4_6
     }
 
 
+    /*! This is used in the documentation of a file/namespace before the list 
+     *  of documentation blocks for enumeration values
+     */
+    virtual QCString trEnumerationValueDocumentation()
+    { 
+      return decode("Dokumentace vtovch hodnot"); 
+    }
 };
 
 #endif // TRANSLATOR_CZ_H
