@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -65,24 +65,26 @@
 // 2005/03/21
 // - Added strings for 1.4.1
 //
-
+// 2006/06/11
+// - Added strings for 1.4.6
+//
 #ifndef TRANSLATOR_HR_H
 #define TRANSLATOR_HR_H
 
-class TranslatorCroatian : public TranslatorAdapter_1_4_6
+class TranslatorCroatian : public Translator
 {
   private:
         /*! to avoid macro redefinition from translator_cz.h */
         inline QCString decode(const QCString& sInput)
         { 
-          if (Config_getBool("USE_WINDOWS_ENCODING"))
-          {
-            return ISO88592ToWin1250(sInput);
-          }
-          else
-          {
+          //if (Config_getBool("USE_WINDOWS_ENCODING"))
+          //{
+          //  return ISO88592ToWin1250(sInput);
+          //}
+          //else
+          //{
             return sInput;
-          }
+          //}
         }
   
   public:
@@ -90,14 +92,14 @@ class TranslatorCroatian : public TranslatorAdapter_1_4_6
     { return "croatian"; }
     QCString idLanguageCharset()
     {
-      if (Config_getBool("USE_WINDOWS_ENCODING"))
-      {
-        return "windows-1250"; 
-      }
-      else
-      {
+      //if (Config_getBool("USE_WINDOWS_ENCODING"))
+      //{
+      //  return "windows-1250"; 
+      //}
+      //else
+      //{
         return "iso-8859-2";
-      }
+      //}
     }
     QCString latexLanguageSupportCommand()
     { return "\\usepackage[croatian]{babel}\n"; }
@@ -755,6 +757,8 @@ class TranslatorCroatian : public TranslatorAdapter_1_4_6
         "class Undocumented { };\n\n"
         "/*! Klasa koja je naslijeena public  */\n"
         "class PublicBase : public Truncated { };\n\n"
+        "/*! A template class */\n"
+        "template<class T> class Templ { };\n\n"
         "/*! Klasa koje je naslijeena protected */\n"
         "class ProtectedBase { };\n\n"
         "/*! Klasa koje je naslijeena private */\n"
@@ -765,7 +769,8 @@ class TranslatorCroatian : public TranslatorAdapter_1_4_6
         "class Inherited : public PublicBase,\n"
         "                  protected ProtectedBase,\n"
         "                  private PrivateBase,\n"
-        "                  public Undocumented\n"
+        "                  public Undocumented,\n"
+        "                  public Templ<int>\n"
         "{\n"
         "  private:\n"
         "    Used *m_usedClass;\n"
@@ -1254,6 +1259,21 @@ class TranslatorCroatian : public TranslatorAdapter_1_4_6
               "samo po vrsti argumenata koje prihvata.");
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.6
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used to introduce a caller (or called-by) graph */
+    virtual QCString trCallerGraph()
+    {
+      return "Ovo je graf funkcija koje pozivaju ovu funkciju:";
+    }
+
+    /*! This is used in the documentation of a file/namespace before the list 
+     *  of documentation blocks for enumeration values
+     */
+    virtual QCString trEnumerationValueDocumentation()
+    { return "Dokumentacija enumeracija"; }
 };
 
 #endif
