@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -29,7 +29,7 @@
 #ifndef TRANSLATOR_HU_H
 #define TRANSLATOR_HU_H
 
-class TranslatorHungarian : public Translator
+class TranslatorHungarian : public TranslatorAdapter_1_4_6
 {
   private:
     const char * zed(char c)
@@ -56,7 +56,8 @@ class TranslatorHungarian : public Translator
      */
     virtual QCString latexLanguageSupportCommand()
     {
-      return "\\usepackage{t1enc}\n\\usepackage[latin2]{inputenc}\n\\usepackage[magyar]{babel}\n";
+      return "\\usepackage[T2A]{fontenc}\n"
+             "\\usepackage[magyar]{babel}\n";
     }
 
     /*! return the language charset. This will be used for the HTML output */
@@ -1017,7 +1018,7 @@ class TranslatorHungarian : public Translator
         "class Inherited : public PublicBase,\n"
         "                  protected ProtectedBase,\n"
         "                  private PrivateBase,\n"
-        "                  public Undocumented\n"
+        "                  public Undocumented,\n"
         "                  public Templ<int>\n"
         "{\n"
         "  private:\n"
