@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -19,6 +19,8 @@
  *
  * Revision history
  *
+ *  2006/10: made class to derive directly from Translator class (reported in Petr Prikryl October 9 translator report)
+ *  2006/06: updated translation of new items used since version 1.4.6
  *  2006/05: translated new items used since version 1.4.6
  *           corrected typo in trPackageMembers method
  *  2005/03: translated new items used since version 1.4.1
@@ -76,7 +78,7 @@
 #ifndef TRANSLATOR_IT_H
 #define TRANSLATOR_IT_H
 
-class TranslatorItalian : public TranslatorAdapter_1_4_6
+class TranslatorItalian : public Translator
 {
   public:
 
@@ -1027,6 +1029,8 @@ class TranslatorItalian : public TranslatorAdapter_1_4_6
         "class Undocumented { };\n\n"
         "/*! Classe che utilizza una ereditariet pubblica */\n"
         "class PublicBase : public Truncated { };\n\n"
+        "/*! A template class */\n"
+        "template<class T> class Templ { };\n\n"
         "/*! Classe che utilizza una ereditariet protetta*/\n"
         "class ProtectedBase { };\n\n"
         "/*! Classe che utilizza una ereditariet  privata*/\n"
@@ -1037,7 +1041,8 @@ class TranslatorItalian : public TranslatorAdapter_1_4_6
         "class Inherited : public PublicBase,\n"
         "                  protected ProtectedBase,\n"
         "                  private PrivateBase,\n"
-        "                  public Undocumented\n"
+        "                  public Undocumented,\n"
+        "                  public Templ<int>\n"
         "{\n"
         "  private:\n"
         "    Used *m_usedClass;\n"
@@ -1530,11 +1535,18 @@ class TranslatorItalian : public TranslatorAdapter_1_4_6
 // new since 1.4.6
 //////////////////////////////////////////////////////////////////////////
 
+    /*! This is used to introduce a caller (or called-by) graph */
     virtual QCString trCallerGraph()
     {
       return "Questo  il grafo dei chiamanti di questa funzione:";
     }
 
+    /*! This is used in the documentation of a file/namespace before the list 
+     *  of documentation blocks for enumeration values
+     */
+    virtual QCString trEnumerationValueDocumentation()
+    { return "Documentazione dei tipi enumerati"; }
+
 };
 
 #endif
