@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -29,39 +29,39 @@
 #ifndef TRANSLATOR_JP_H
 #define TRANSLATOR_JP_H
 
-class TranslatorJapanese : public TranslatorAdapter_1_3_9
+class TranslatorJapanese : public Translator
 {
  private:
   /*! The decode() can change euc into sjis */
   inline QCString decode(const QCString & sInput)
   {
-    if (Config_getBool("USE_WINDOWS_ENCODING"))
-    {
-      return JapaneseEucToSjis(sInput);
-    }
-    else
-    {
+    //if (Config_getBool("USE_WINDOWS_ENCODING"))
+    //{
+    //  return JapaneseEucToSjis(sInput);
+    //}
+    //else
+    //{
       return sInput;
-    }
+    //}
   }
   public:
     virtual QCString idLanguage()
     { return "japanese"; }
     virtual QCString latexLanguageSupportCommand()
-      {
-	return "";
-      }
+    {
+      return "";
+    }
     /*! returns the name of the package that is included by LaTeX */
     virtual QCString idLanguageCharset()
     {
-      if (Config_getBool("USE_WINDOWS_ENCODING"))
-      {
-        return "Shift_JIS";
-      }
-      else
-      {
+      //if (Config_getBool("USE_WINDOWS_ENCODING"))
+      //{
+      //  return "Shift_JIS";
+      //}
+      //else
+      //{
         return "euc-jp";
-      }
+      //}
     }
 
     /*! used in the compound documentation before a list of related functions. */
@@ -453,12 +453,6 @@ class TranslatorJapanese : public TranslatorAdapter_1_3_9
     virtual QCString trEnumerationTypeDocumentation()
     { return decode(""); }
 
-    /*! This is used in the documentation of a file/namespace before the list
-     *  of documentation blocks for enumeration values
-     */
-    virtual QCString trEnumerationValueDocumentation()
-    { return decode("󷿤"); }
-
     /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for functions
      */
@@ -1007,6 +1001,8 @@ class TranslatorJapanese : public TranslatorAdapter_1_3_9
         "class Undocumented { };\n\n"
         "/*! public ǷѾ줿饹 */\n"
         "class PublicBase : public Truncated { };\n\n"
+        "/*! A template class */\n"
+        "template<class T> class Templ { };\n\n"
         "/*! protected ǷѾ줿饹 */\n"
         "class ProtectedBase { };\n\n"
         "/*! private ǷѾ줿饹 */\n"
@@ -1017,7 +1013,8 @@ class TranslatorJapanese : public TranslatorAdapter_1_3_9
         "class Inherited : public PublicBase,\n"
         "                  protected ProtectedBase,\n"
         "                  private PrivateBase,\n"
-        "                  public Undocumented\n"
+        "                  public Undocumented,\n"
+        "                  public Templ<int>\n"
         "{\n"
         "  private:\n"
         "    Used *m_usedClass;\n"
@@ -1341,7 +1338,7 @@ class TranslatorJapanese : public TranslatorAdapter_1_3_9
      */
     virtual QCString trImplementedFromList(int numEntries)
     {
-      return trWriteList(numEntries)+decode("Ƥޤ")+".";
+      return trWriteList(numEntries)+decode("Ƥޤ");
     }
 
     /*! used in member documentation blocks to produce a list of
@@ -1349,7 +1346,7 @@ class TranslatorJapanese : public TranslatorAdapter_1_3_9
      */
     virtual QCString trImplementedInList(int numEntries)
     {
-      return trWriteList(numEntries)+decode("ǼƤޤ")+".";
+      return trWriteList(numEntries)+decode("ǼƤޤ");
     }
 //////////////////////////////////////////////////////////////////////////
 // new since 1.2.16
@@ -1509,5 +1506,81 @@ class TranslatorJapanese : public TranslatorAdapter_1_3_9
     {
       return filename + decode(" ե");
     }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return decode("ǥ쥯ȥ"); }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return decode("ǥ쥯ȥ깽"); }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of an HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return decode("ǥ쥯ȥ"); }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { return decode("Υǥ쥯ȥϤޤˤϥȤƤޤ"
+		    "˥ե٥åȽǥȤƤϤޤ");
+    }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    { QCString result=dirName; result+=decode(" ǥ쥯ȥե"); return result; }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool, bool)
+    { 
+      return decode("ǥ쥯ȥ");
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+       return decode("ϥСɤ줿дؿǤ"
+		     "ΤѰդƤޤ"
+		     "δؿȤΰ㤤ϰΤߤǤ");
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.6
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used to introduce a caller (or called-by) graph */
+    virtual QCString trCallerGraph()
+    {
+      // return "Here is the caller graph for this function:";
+      return decode("ƽФ:");
+    }
+
+    /*! This is used in the documentation of a file/namespace before the list
+     *  of documentation blocks for enumeration values
+     */
+    virtual QCString trEnumerationValueDocumentation()
+    { return decode(""); }
+
 };
 #endif
