@@ -2,7 +2,7 @@
  *
  * $Id: translator_nl.h,v 1.22 2001/03/19 19:27:42 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -91,8 +91,6 @@ class TranslatorDutch : public Translator
     { return "Klasse Lijst"; }
     QCString trFileList()
     { return "File Lijst"; }
-    QCString trHeaderFiles()
-    { return "Header Lijst"; }
     QCString trCompoundMembers()
     { return "Klasse Members"; }
     QCString trFileMembers()
@@ -136,16 +134,12 @@ class TranslatorDutch : public Translator
       else result+="de files waartoe ze behoren:";
       return result;
     }
-    QCString trHeaderFilesDescription()
-    { return "Hieronder volgen de header files die de API vormen:"; }
     QCString trExamplesDescription()
     { return "Hieronder volgt de lijst met alle voorbeelden:"; }
     QCString trRelatedPagesDescription()
     { return "Hieronder volgt de lijst met alle pagina's die gerelateerde documentatie bevatten:"; }
     QCString trModulesDescription()
     { return "Hieronder volgt de lijst met alle modules:"; }
-    QCString trNoDescriptionAvailable()
-    { return "Geen korte beschrijving beschikbaar"; }
 
     QCString trDocumentation()
     { return "Documentatie"; }
@@ -217,14 +211,8 @@ class TranslatorDutch : public Translator
     }
     QCString trForInternalUseOnly()
     { return "Alleen voor intern gebruik."; }
-    QCString trReimplementedForInternalReasons()
-    { return "Om interne redenen opnieuwd ge&iuml;mplemented; "
-             "de API wordt er niet door be&iuml;nvloed."; 
-    }
     QCString trWarning()
     { return "Waarschuwing"; }
-    QCString trBugsAndLimitations()
-    { return "Fouten en beperkingen"; }
     QCString trVersion()
     { return "Versie"; }
     QCString trDate()
@@ -466,10 +454,6 @@ class TranslatorDutch : public Translator
 // new since 0.49-991106
 //////////////////////////////////////////////////////////////////////////
 
-    QCString trSources()
-    {
-      return "Broncode";
-    }
     QCString trDefinedAtLineInSourceFile()
     {
       return "De definitie bevindt zich op regel @0 in de file @1.";
@@ -671,6 +655,8 @@ class TranslatorDutch : public Translator
         "class Undocumented { };\n\n"
         "/*! Klasse met public inheritance */\n"
         "class PublicBase : public Truncated { };\n\n"
+        "/*! A template class */\n"
+        "template<class T> class Templ { };\n\n"
         "/*! Klasse met protected inheritance */\n"
         "class ProtectedBase { };\n\n"
         "/*! Klasse met private inheritance */\n"
@@ -681,7 +667,8 @@ class TranslatorDutch : public Translator
         "class Inherited : public PublicBase,\n"
         "                  protected ProtectedBase,\n"
         "                  private PrivateBase,\n"
-        "                  public Undocumented\n"
+        "                  public Undocumented,\n"
+        "                  public Templ<int>\n"
         "{\n"
         "  private:\n"
         "    Used *m_usedClass;\n"
@@ -693,7 +680,7 @@ class TranslatorDutch : public Translator
         "<p>\n"
         "De rechthoeken in the bovenstaande graaf hebben de volgende betekenis:\n"
         "<ul>\n"
-        "<li>Een gevulde zwarte rechthoek representeert de structure of klasse waarvoor "
+        "<li>Een gevulde grijze rechthoek representeert de structure of klasse waarvoor "
         "de graaf is gegeneerd.\n"
         "<li>Een rechthoek met een zwarte rand representeert een gedocumenteerde structure of klasse.\n"
         "<li>Een rechthoek met een grijze rand representeert een ongedocumenteerde structure of klasse.\n"
@@ -765,11 +752,6 @@ class TranslatorDutch : public Translator
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    QCString trInterfaces()
-    {
-      return "Interfaces";
-    }
     /*! Used for Java classes in the summary section of Java packages */
     QCString trClasses()
     {
@@ -795,11 +777,6 @@ class TranslatorDutch : public Translator
     {
       return "Packages";
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    QCString trPackageDocumentation()
-    {
-      return "Package Documentatie";
-    }
     /*! Text shown before a multi-line define */
     QCString trDefineValue()
     {
@@ -936,17 +913,6 @@ class TranslatorDutch : public Translator
       return result; 
     }
    
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
-     *  of the category.
-     */
-    virtual QCString trField(bool first_capital, bool singular)
-    { 
-      QCString result((first_capital ? "Veld" : "veld"));
-      if (!singular)  result+="en";
-      return result; 
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names 
      *  of the category.
@@ -1200,6 +1166,29 @@ class TranslatorDutch : public Translator
       return result; 
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a function.
+     */
+    virtual QCString trOverloadText()
+    {
+      return "Deze functie is overloaded en is beschikbaar gemaakt om het "
+             "gebruik te vergemakkelijken. Ze verschilt alleen van de "
+             "bovenstaande functie wat betreft de parameterlijst.";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.6
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Put in front of the call graph for a function. */
+    virtual QCString trCallerGraph()
+    {
+      return "Hier is de caller graaf voor deze functie:";
+    }
     
 };
 
