@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -26,14 +26,14 @@ class TranslatorPolish : public TranslatorAdapter_1_4_6
     /*! to avoid macro redefinition from translator_pl.h */
     inline QCString decode(const QCString& sInput)
     { 
-      if (Config_getBool("USE_WINDOWS_ENCODING"))
-      {
-        return ISO88592ToWin1250(sInput);
-      }  
-      else
-      {   
+      //if (Config_getBool("USE_WINDOWS_ENCODING"))
+      //{
+      //  return ISO88592ToWin1250(sInput);
+      //}  
+      //else
+      //{   
         return sInput;  
-      }  
+      //}  
     }
   public:
 
@@ -55,20 +55,21 @@ class TranslatorPolish : public TranslatorAdapter_1_4_6
      */
     QCString latexLanguageSupportCommand()
     {
-      return "\\usepackage{polski} \\usepackage[latin2]{inputenc} \\usepackage[T1]{fontenc}";
+      return "\\usepackage{polski}\n"
+             "\\usepackage[T1]{fontenc}\n";
     }
 
     /*! return the language charset. This will be used for the HTML output */
     virtual QCString idLanguageCharset()
     {
-      if (Config_getBool("USE_WINDOWS_ENCODING"))
-      {
-        return "windows-1250";
-      }  
-      else
-      {   
+      //if (Config_getBool("USE_WINDOWS_ENCODING"))
+      //{
+      //  return "windows-1250";
+      //}  
+      //else
+      //{   
         return "iso-8859-2"; 
-      }  
+      //}  
     }
     
     // --- Language translation methods -------------------
@@ -1043,6 +1044,8 @@ class TranslatorPolish : public TranslatorAdapter_1_4_6
         "class Nieudokumentowana { };\n\n"
         "/*! Klasa, ktra jest dziedziczona publicznie */\n"
         "class PublicznaBaza : public Okrojona { };\n\n"
+        "/*! A template class */\n"
+        "template<class T> class Templ { };\n\n"
         "/*! Klasa, ktra jest dziedziczona przy uyciu dziedziczenia chronionego */\n"
         "class ChronionaBaza { };\n\n"
         "/*! Klasa, ktra jest dziedziczona prywatnie */\n"
@@ -1053,7 +1056,8 @@ class TranslatorPolish : public TranslatorAdapter_1_4_6
         "class Dziedziczona : public PublicznaBaza,\n"
         "                     protected ChronionaBaza,\n"
         "                     private PrywatnaBaza,\n"
-        "                     public Nieudokumentowana\n"
+        "                     public Nieudokumentowana,\n"
+        "                     public Templ<int>\n"
         "{\n"
         "  private:\n"
         "    Uzyta *m_usedClass;\n"
