@@ -2,7 +2,7 @@
  *
  * $Id: translator_ro.h,v 1.3 2001/03/19 19:27:42 root Exp $
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -75,7 +75,7 @@ class TranslatorRomanian : public TranslatorAdapter_1_4_1
      */
     virtual QCString latexLanguageSupportCommand()
     {
-      return "\\usepackage{romanian}\n";
+      return "\\usepackage[romanian]{babel}\n";
     }
 
     /*! return the language charset. This will be used for the HTML output */
@@ -1073,6 +1073,8 @@ class TranslatorRomanian : public TranslatorAdapter_1_4_1
         "class Undocumented { };\n\n"
         "/*! Clas care este motenit n mod public */\n"
         "class PublicBase : public Truncated { };\n\n"
+        "/*! A template class */\n"
+        "template<class T> class Templ { };\n\n"
         "/*! Clas care este motenit n mod protejat */\n"
         "class ProtectedBase { };\n\n"
         "/*! Clas care este motenit n mod privat */\n"
@@ -1083,7 +1085,8 @@ class TranslatorRomanian : public TranslatorAdapter_1_4_1
         "class Inherited : public PublicBase,\n"
         "                  protected ProtectedBase,\n"
         "                  private PrivateBase,\n"
-        "                  public Undocumented\n"
+        "                  public Undocumented,\n"
+        "                  public Templ<int>\n"
         "{\n"
         "  private:\n"
         "    Used *m_usedClass;\n"
