@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -31,11 +31,11 @@ class TranslatorSlovak : public TranslatorAdapter_1_2_18
 	 */
 	inline QCString Decode(const QCString & sInput)
 	{
-#ifdef _WIN32
+//#ifdef _WIN32
 	  return sInput;
-#else
-	  return Win1250ToISO88592(sInput);
-#endif
+//#else
+//	  return Win1250ToISO88592(sInput);
+//#endif
 	}
 
   public:
@@ -45,16 +45,16 @@ class TranslatorSlovak : public TranslatorAdapter_1_2_18
 	{ return "slovak"; }
 
 	virtual QCString latexLanguageSupportCommand()
-	{ return "\\usepackage{slovak}\n"; }
+	{ return "\\usepackage[slovak]{babel}\n"; }
 
 	/*! return the language charset. This will be used for the HTML output */
 	virtual QCString idLanguageCharset()
 	{
-#ifdef _WIN32
+//#ifdef _WIN32
 		return "windows-1250";
-#else
-		return "iso-8859-2";
-#endif
+//#else
+//		return "iso-8859-2";
+//#endif
 	}
 
 	// --- Language translation methods -------------------
@@ -1055,6 +1055,8 @@ class TranslatorSlovak : public TranslatorAdapter_1_2_18
 		"/*! Odvoden trieda s verejnm (public) dedenm bzovej triedy. */\n"
 		"class PublicBase : public Truncated { };\n\n"
 		"/*! Odvoden trieda s chrnenm (protected) dedenm bzovej triedy. */\n"
+		"/*! A template class */\n"
+		"template<class T> class Templ { };\n\n"
 		"class ProtectedBase { };\n\n"
 		"/*! Odvoden trieda s privtnym dedenm bzovej triedy. */\n"
 		"class PrivateBase { };\n\n"
@@ -1063,9 +1065,10 @@ class TranslatorSlovak : public TranslatorAdapter_1_2_18
 		"/*! Odvoden trieda, ktor rznym spsobom ded od viacerch bzovch "
 		"tried. */\n"
 		"class Inherited : public PublicBase,\n"
-		"				   protected ProtectedBase,\n"
-		"				   private PrivateBase,\n"
-		"				   public Undocumented\n"
+		"                  protected ProtectedBase,\n"
+		"                  private PrivateBase,\n"
+		"                  public Undocumented,\n"
+		"                  public Templ<int>\n"
 		"{\n"
 		"  private:\n"
 		"	 Used *m_usedClass;\n"
