@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -26,7 +26,7 @@
 #ifndef TRANSLATOR_ZA_H
 #define TRANSLATOR_ZA_H
 
-class TranslatorAfrikaans : public Translator
+class TranslatorAfrikaans : public TranslatorAdapter_1_4_6
 {
   public:
 
@@ -1021,7 +1021,7 @@ class TranslatorAfrikaans : public Translator
         "class Inherited : public PublicBase,\n"
         "                  protected ProtectedBase,\n"
         "                  private PrivateBase,\n"
-        "                  public Ongedokumenteer\n"
+        "                  public Ongedokumenteer,\n"
         "                  public Templ<int>\n"  
         "{\n"
         "  private:\n"
