@@ -2,7 +2,7 @@
  *
  * $Id: util.h,v 1.49 2001/03/19 19:27:42 root Exp $
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -175,7 +175,8 @@ ClassDef *getResolvedClass(Definition *scope,
                            MemberDef **pTypeDef=0,
                            QCString *pTemplSpec=0,
                            bool mayBeUnlinkable=FALSE,
-                           bool mayBeHidden=FALSE);
+                           bool mayBeHidden=FALSE,
+                           QCString *pResolvedType=0);
 
 NamespaceDef *getResolvedNamespace(const char *key);
 
@@ -220,7 +221,7 @@ void initClassHierarchy(ClassSDict *cl);
 
 bool hasVisibleRoot(BaseClassList *bcl);
 
-int minClassDistance(ClassDef *cd,ClassDef *bcd,int level=0);
+int minClassDistance(const ClassDef *cd,const ClassDef *bcd,int level=0);
 
 QCString convertNameToFile(const char *name,bool allowDots=FALSE);
 
@@ -232,17 +233,15 @@ QCString insertTemplateSpecifierInScope(const QCString &scope,const QCString &te
 
 QCString stripScope(const char *name);
 
-int iSystem(const char *command,const char *args,bool commandHasConsole=TRUE);
-
 QCString convertToHtml(const char *s);
 
 QCString convertToXML(const char *s);
 
 QCString getOverloadDocs();
 
-void addMembersToMemberGroup(MemberList *ml,
-                             MemberGroupSDict *memberGroupSDict,
-                             Definition *context);
+void addMembersToMemberGroup(/* in */     MemberList *ml,
+                             /* in,out */ MemberGroupSDict **ppMemberGroupSDict,
+                             /* in */     Definition *context);
 
 int extractClassNameFromType(const QCString &type,int &pos,
                               QCString &name,QCString &templSpec);
@@ -325,7 +324,15 @@ SrcLangExt getLanguageFromFileName(const QCString fileName);
 
 bool checkIfTypedef(Definition *scope,FileDef *fileScope,const char *n);
 
+ClassDef *newResolveTypedef(FileDef *fileScope,MemberDef *md,
+                            MemberDef **pMemType=0,QCString *pTemplSpec=0,
+                            QCString *pResolvedType=0);
 
+QCString parseCommentAsText(const QString &doc,const QCString &fileName,int lineNr);
+
+QCString transcodeCharacterStringToUTF8(const QCString &input);
+
+QCString recodeString(const QCString &str,const char *fromEncoding,const char *toEncoding);
 
 #endif
 
