@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2007 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -208,6 +208,11 @@ void XmlDocVisitor::visit(DocVerbatim *s)
       filter(s->text());
       m_t << "</dot>";
       break;
+    case DocVerbatim::Msc: 
+      m_t << "<msc>";
+      filter(s->text());
+      m_t << "</msc>";
+      break;
   }
 }
 
@@ -721,7 +726,7 @@ void XmlDocVisitor::visitPost(DocRef *ref)
 {
   if (m_hide) return;
   if (!ref->file().isEmpty()) endLink();
-  m_t << " ";
+  //m_t << " ";
 }
 
 void XmlDocVisitor::visitPre(DocSecRefItem *ref)
